@@ -57,6 +57,17 @@
  * are either from tokens (given g_strsplit()) or strings.</para>
  */
 
+static GQuark quark;
+
+void configFileInit()
+{
+  quark = g_quark_from_static_string("visu_configFile");
+}
+GQuark configFileGet_quark()
+{
+  return quark;
+}
+
 gboolean configFileRead_floatFromTokens(gchar **tokens, int *position, float *values,
 					guint size, int lineId, GError **error)
 {
