@@ -51,6 +51,7 @@
 #include <GL/glu.h> 
 
 #include <visu_tools.h>
+#include <visu_basic.h>
 #include <openGLFunctions/text.h>
 
 /**
@@ -128,7 +129,7 @@ gboolean shadeSet_pathToImage(Shade *shade, const gchar* path)
   g_return_val_if_fail(shade, FALSE);
 
   if (!g_path_is_absolute(path))
-    absPath = g_build_filename(v_sim_pixmaps_dir, path, NULL);
+    absPath = g_build_filename(V_SIM_PIXMAPS_DIR, path, NULL);
   else
     absPath = g_strdup(path);
 
