@@ -179,11 +179,11 @@ OpenGLExtension* extFogAndBGInit()
   bgImage      = (guchar*)0;
   bgImageTitle = (gchar*)0;
 
-  g_signal_connect(G_OBJECT(visu), "resourcesLoaded",
+  g_signal_connect(VISU_INSTANCE, "resourcesLoaded",
 		   G_CALLBACK(rebuildFogOnResources), (gpointer)0);
-  g_signal_connect(G_OBJECT(visu), "dataReadyForRendering",
+  g_signal_connect(VISU_INSTANCE, "dataReadyForRendering",
 		   G_CALLBACK(onDataReadySignal), (gpointer)0);
-  g_signal_connect(G_OBJECT(visu), "dataNew",
+  g_signal_connect(VISU_INSTANCE, "dataNew",
 		   G_CALLBACK(onDataNewSignal), (gpointer)0);
 
   return extensionFog;
