@@ -229,11 +229,11 @@ static void scale_class_init(ScaleClass *klass)
 				   exportResourcesScale);
 
   /* Connect external signals. */
-  g_signal_connect(G_OBJECT(visu), "dataReadyForRendering",
+  g_signal_connect(VISU_INSTANCE, "dataReadyForRendering",
 		   G_CALLBACK(onDataReadySignal), (gpointer)klass);
-  g_signal_connect(G_OBJECT(visu), "dataNew",
+  g_signal_connect(VISU_INSTANCE, "dataNew",
 		   G_CALLBACK(onDataNewSignal), (gpointer)klass);
-  g_signal_connect(G_OBJECT(visu), "resourcesLoaded",
+  g_signal_connect(VISU_INSTANCE, "resourcesLoaded",
  		   G_CALLBACK(rebuildScaleOnResourcesLoaded), (gpointer)klass);
 
   scaleHasBeenBuilt = FALSE;
@@ -873,6 +873,9 @@ static void lineDraw(VisuData *dataObj _U_, int nlat, Scale *scale)
   float angles[3]; /*declaration des tableaux angles et coordonnées a 3 cellules*/
   float coord[3];
   float radius = 0.3;
+  GLUquadricObj *obj;
+
+  obj = gluNewQuadric();
 
   norm = scale->length / sqrt(scale->direction[0] * scale->direction[0] +
 		       scale->direction[1] * scale->direction[1] +
