@@ -52,6 +52,34 @@
 #include <visu_tools.h>
 #include <coreTools/toolFileFormat.h>
 #include <coreTools/toolMatrix.h>
+#include "surfaces_points.h"
+#include "isoline.h"
+
+/**
+ * SECTION:scalarFields
+ * @short_description:Gives capabilities to load a scalar field.
+ *
+ * <para>A scalar field is represented by the given of datas on a
+ * regular grid meshing the bounding box. Scalar field can be read
+ * from several kind of files by adding load methods using
+ * scalarFieldAdd_loadMethod(). The basic implementation gives access
+ * to ASCII encoded files following a simple format.</para>
+ *
+ * <para>In coordination with #Plane and #Shade, scalar field can be
+ * represented as coloured map calling scalarFieldDraw_map(). The
+ * current implementation of interpolation is very limited since basic
+ * linear approximation is used.</para>
+ *
+ * <para>If a structure file also contains a scalar field, when
+ * loaded, it should add a #VisuData property called
+ * #SCALAR_FIELD_DEFINED_IN_STRUCT_FILE using
+ * visuDataAdd_property(). Then V_Sim will be able to handle the
+ * structure file as a density file also.</para>
+ */
+
+#define MESH_FLAG             "meshType"
+#define MESH_FLAG_UNIFORM     "uniform"
+#define MESH_FLAG_NON_UNIFORM "nonuniform"
 
 /**
  * ScalarField_struct:
@@ -82,17 +110,41 @@ struct ScalarField_struct
   /* Number of elements in each directions [x, y, z]. */
   int nElements[3];
 
+  /* Mesh. */
+  double *meshx;
+  double *meshy;
+  double *meshz;
+
   /* Datas. */
   double ***data;
 
   /* Minimum and maximum values. */
-  double min, max;
-  
+  double min, max, secondMin;
+
+  /* Set to TRUE if the data can replicate by periodicity. */
+  gboolean periodic;
+
+  /* mesh type: uniform or non uniform */
+  ScalarField_meshflag mesh_type;
+
   /* A GList to store some options (key, values) associated
      to the data. */
   GList *options;
 };
 
+enum
+  {
+    MAP_X,
+    MAP_Y,
+    MAP_Z,
+    MAP_VISIBILITY,
+    MAP_VALUE,
+    MAP_R,
+    MAP_G,
+    MAP_B,
+    MAP_A
+  };
+
 /* Local variables. */
 static GList *loadMethods;
 
@@ -108,16 +160,22 @@ ScalarField* scalarFieldNew(const gchar *filename)
 
   g_return_val_if_fail(filename && filename[0], (ScalarField*)0);
 
-  field = g_malloc(sizeof(ScalarField));
+  field               = g_malloc(sizeof(ScalarField));
   field->nElements[0] = 0;
   field->nElements[1] = 0;
   field->nElements[2] = 0;
-  field->filename = g_strdup(filename);
-  field->commentary = (gchar*)0;
-  field->data = (double***)0;
-  field->min = G_MAXFLOAT;
-  field->max = G_MINFLOAT;
-  field->options = (GList*)0;
+  field->filename     = g_strdup(filename);
+  field->commentary   = (gchar*)0;
+  field->meshx        = (double*)0;
+  field->meshy        = (double*)0;
+  field->meshz        = (double*)0;
+  field->data         = (double***)0;
+  field->min          = G_MAXFLOAT;
+  field->max          = -G_MAXFLOAT;
+  field->secondMin    = G_MAXFLOAT;
+  field->periodic     = FALSE;
+  field->mesh_type    = uniform;
+  field->options      = (GList*)0;
 
   return field;
 }
@@ -134,6 +192,15 @@ void scalarFieldFree(ScalarField *field)
   if (field->commentary)
     g_free(field->commentary);
 
+  if (field->meshx)
+    g_free(field->meshx);
+
+  if (field->meshy)
+    g_free(field->meshy);
+
+  if (field->meshz)
+    g_free(field->meshz);
+
   if (field->data)
     {
       for (i = 0; i < field->nElements[0]; i++)
@@ -144,7 +211,7 @@ void scalarFieldFree(ScalarField *field)
 	}
       g_free(field->data);
     }
-    
+
   if (field->options)
     {
       tmplst = field->options;
@@ -185,21 +252,25 @@ gboolean scalarFieldLoad_fromFile(const gchar *filename, GList **fieldList,
   
   if (!validFormat)
     g_set_error(error, VISU_FILEFORMAT_ERROR, FILEFORMAT_ERROR_UNKNOWN_FORMAT, 
-		_("WARNING : unknown density/potential format.\n")); 
+		_("unknown density/potential format.\n")); 
   return validFormat;
 }
 
 
-static gboolean scalarFieldLoad_fromAscii(const gchar *filename, GList **fieldList, GError **error,
-					  OptionTable *table)
+static gboolean scalarFieldLoad_fromAscii(const gchar *filename, GList **fieldList,
+					  GError **error, OptionTable *table _U_)
 {
   FILE *in;
-  char rep[MAX_LINE_LENGTH], format[MAX_LINE_LENGTH];
+  char rep[MAX_LINE_LENGTH], flag[MAX_LINE_LENGTH];
+  char format[MAX_LINE_LENGTH], period[MAX_LINE_LENGTH];
+  char *feed;
   gchar *comment;
   int res, i, j, k;
   int size[3];
   float box[6];
   ScalarField *field;
+  gboolean periodic;
+  ScalarField_meshflag meshtype;
 
   g_return_val_if_fail(filename, FALSE);
   g_return_val_if_fail(*fieldList == (GList*)0, FALSE);
@@ -212,15 +283,17 @@ static gboolean scalarFieldLoad_fromAscii(const gchar *filename, GList **fieldLi
   if (!in)
     {
       g_set_error(error, G_FILE_ERROR, G_FILE_ERROR_ACCES,
-		  _("WARNING : impossible to open the file.\n"));
+		  _("impossible to open the file.\n"));
       return FALSE;
     }
 
   /* 1st line (comment) */
   (void)fgets(rep, MAX_LINE_LENGTH, in);
   rep[strlen(rep)-1] = 0; /* skipping \n */
-  comment = getStringInUTF8(rep);
-   
+  comment = g_locale_to_utf8(rep, -1, NULL, NULL, NULL);
+  if (!comment)
+    comment = g_strdup("");
+
   (void)fgets(rep, MAX_LINE_LENGTH, in);
   res = sscanf(rep, "%d %d %d", size, size + 1, size + 2);
   if (res != 3)
@@ -251,14 +324,15 @@ static gboolean scalarFieldLoad_fromAscii(const gchar *filename, GList **fieldLi
     }
 
   (void)fgets(rep, MAX_LINE_LENGTH, in);
-  res = sscanf(rep, "%s", format);
-  if (res != 1 || (strcmp(format, "xyz") && strcmp(format, "zyx")))
+  res = sscanf(rep, "%s %s", format, period);
+  if (res < 1 || (strcmp(format, "xyz") && strcmp(format, "zyx")))
     {
       /* Not a valid ASCII format. */
       g_free(comment);
       fclose(in);
       return FALSE;
     }
+  periodic = !strcmp(period, "periodic");
 
   /* OK, from now on, the format is supposed to be ASCII. */
   field = scalarFieldNew(filename);
@@ -269,25 +343,132 @@ static gboolean scalarFieldLoad_fromAscii(const gchar *filename, GList **fieldLi
       fclose(in);
       return FALSE;
     }
+
+  /* by default the meshtype is set to uniform to keep working previous version.*/
+  meshtype = uniform;
+  feed = fgets(rep, MAX_LINE_LENGTH, in);
+  while (rep[0] == '#' && feed)
+    {
+      if (strncmp(rep + 2, MESH_FLAG, strlen(MESH_FLAG)) == 0)
+	{
+	  DBG_fprintf(stderr, "ScalarField: found flag '%s'.\n", MESH_FLAG);
+	  res = sscanf(rep + 2 + strlen(MESH_FLAG) + 1, "%s", flag);
+	  if (res == 1 && strcmp(flag, MESH_FLAG_UNIFORM) == 0)
+	    meshtype = uniform;
+	  else if (res == 1 && strcmp(flag, MESH_FLAG_NON_UNIFORM) == 0)
+	    meshtype = nonuniform;
+	  else if (res == 1)
+	    {
+              g_set_error(error, VISU_FILEFORMAT_ERROR, FILEFORMAT_ERROR_FORMAT,
+			  _("wrong '%s' value for flag '%s'.\n"), flag, MESH_FLAG);
+              fclose(in);
+              return TRUE;
+	    }
+	}
+      feed = fgets(rep, MAX_LINE_LENGTH, in);
+    }
+
+  scalarFieldSet_periodic(field, periodic);
   scalarFieldSet_commentary(field, comment);
+  scalarFieldSet_meshtype(field, meshtype);
   scalarFieldSet_gridSize(field, size);
   scalarFieldSet_box(field, box);
   *fieldList = g_list_append(*fieldList, (gpointer)field);
- 
-  /* TODO change the error flag. */
+
+  if (meshtype == nonuniform)
+    {
+      DBG_fprintf(stderr, "ScalarField : Start to read meshx.\n");
+
+      for ( i = 0; i < size[0]; i++ )
+        {
+	  if (!feed)
+	    {
+	      g_set_error(error, VISU_FILEFORMAT_ERROR, FILEFORMAT_ERROR_FORMAT,
+			  _("not enough meshx values.\n"));
+	      fclose(in);
+	      return TRUE;
+	    }
+          res = sscanf(rep, "%lf", &field->meshx[i]);
+	  do feed = fgets(rep, MAX_LINE_LENGTH, in); while (rep[0] == '#' && feed);
+          if (res != 1)
+            {
+              g_set_error(error, VISU_FILEFORMAT_ERROR, FILEFORMAT_ERROR_FORMAT,
+			  _("impossible to read meshx values.\n"));
+              fclose(in);
+              return TRUE;
+            }
+        }
+
+      DBG_fprintf(stderr, "ScalarField : Start to read meshy.\n");
+
+      for ( j = 0; j < size[1]; j++ )
+        {
+	  if (!feed)
+	    {
+	      g_set_error(error, VISU_FILEFORMAT_ERROR, FILEFORMAT_ERROR_FORMAT,
+			  _("not enough meshy values.\n"));
+	      fclose(in);
+	      return TRUE;
+	    }
+          res = sscanf(rep, "%lf", &field->meshy[j]);
+	  do feed = fgets(rep, MAX_LINE_LENGTH, in); while (rep[0] == '#' && feed);
+          if (res != 1)
+            {
+              g_set_error(error, VISU_FILEFORMAT_ERROR, FILEFORMAT_ERROR_FORMAT,
+			  _("impossible to read meshy values.\n"));
+              fclose(in);
+              return TRUE;
+            }
+        }
+
+      DBG_fprintf(stderr, "ScalarField : Start to read meshz.\n");
+
+      for ( k = 0; k < size[2]; k++ )
+        {
+	  if (!feed)
+	    {
+	      g_set_error(error, VISU_FILEFORMAT_ERROR, FILEFORMAT_ERROR_FORMAT,
+			  _("not enough meshz values.\n"));
+	      fclose(in);
+	      return TRUE;
+	    }
+          res = sscanf(rep, "%lf", &field->meshz[k]);
+	  do feed = fgets(rep, MAX_LINE_LENGTH, in); while (rep[0] == '#' && feed);
+          if (res != 1)
+            {
+              g_set_error(error, VISU_FILEFORMAT_ERROR, FILEFORMAT_ERROR_FORMAT,
+			  _("impossible to read meshz values.\n"));
+              fclose(in);
+              return TRUE;
+            }
+        }
+    }
+
+  DBG_fprintf(stderr, "ScalarField : Start to read data.\n");
+
   field->min = G_MAXFLOAT;
   field->max = G_MINFLOAT;
   if(!strcmp(format, "xyz"))
-    {   
+    {
       for ( k = 0; k < size[2]; k++ ) 
 	for ( j = 0; j < size[1]; j++ ) 
 	  for ( i = 0; i < size[0]; i++ ) 
 	    {
-	      res = fscanf(in, "%lf", &field->data[i][j][k]);
+	      if (!feed)
+		{
+		  g_set_error(error, VISU_FILEFORMAT_ERROR, FILEFORMAT_ERROR_FORMAT,
+			      _("not enough density values.\n"));
+		  fclose(in);
+		  return TRUE;
+		}
+
+	      res = sscanf(rep, "%lf", &field->data[i][j][k]);
+
+	      do feed = fgets(rep, MAX_LINE_LENGTH, in); while (rep[0] == '#' && feed);
 	      if (res != 1)
 		{
 		  g_set_error(error, VISU_FILEFORMAT_ERROR, FILEFORMAT_ERROR_FORMAT,
-			      _("WARNING : impossible to read the density value.\n"));
+			      _("impossible to read density values.\n"));
 		  fclose(in);
 		  return TRUE;
 		}
@@ -301,11 +482,19 @@ static gboolean scalarFieldLoad_fromAscii(const gchar *filename, GList **fieldLi
 	for ( j = 0; j < size[1]; j++ ) 
 	  for ( k = 0; k < size[2]; k++ ) 
 	    {
-	      res = fscanf(in, "%lf", &field->data[i][j][k]);
+	      if (!feed)
+		{
+		  g_set_error(error, VISU_FILEFORMAT_ERROR, FILEFORMAT_ERROR_FORMAT,
+			      _("not enough density values.\n"));
+		  fclose(in);
+		  return TRUE;
+		}
+	      res = sscanf(rep, "%lf", &field->data[i][j][k]);
+	      do feed = fgets(rep, MAX_LINE_LENGTH, in); while (rep[0] == '#' && feed);
 	      if (res != 1)
 		{
 		  g_set_error(error, VISU_FILEFORMAT_ERROR, FILEFORMAT_ERROR_FORMAT,
-			      _("WARNING : impossible to read the density value.\n"));
+			      _("impossible to read density values.\n"));
 		  fclose(in);
 		  return TRUE;
 		}
@@ -330,11 +519,35 @@ void scalarFieldSet_commentary(ScalarField *field, gchar* comment)
   field->commentary = g_strdup(comment);
 }
 
+gboolean scalarFieldGet_periodic(ScalarField *field)
+{
+  g_return_val_if_fail(field, FALSE);
+  return field->periodic;
+}
+void scalarFieldSet_periodic(ScalarField *field, gboolean periodic)
+{
+  g_return_if_fail(field);
+  
+  field->periodic = periodic;
+}
+
+ScalarField_meshflag scalarFieldGet_meshtype(ScalarField *field)
+{
+  g_return_val_if_fail(field, uniform);
+  return field->mesh_type;
+}
+
+void scalarFieldSet_meshtype(ScalarField *field, ScalarField_meshflag meshtype)
+{
+  g_return_if_fail(field);
+
+  field->mesh_type = meshtype;
+}
 
 gchar* scalarFieldGet_filename(ScalarField *field)
 {
   g_return_val_if_fail(field, (gchar*)0);
-  return field->filename;  
+  return field->filename;
 }
 
 void scalarFieldSet_gridSize(ScalarField *field, int grid[3])
@@ -351,6 +564,20 @@ void scalarFieldSet_gridSize(ScalarField *field, int grid[3])
   DBG_fprintf(stderr, "ScalarField : changing size from (%d ; %d ; %d)"
                       " to (%d ; %d ; %d).\n", field->nElements[0], field->nElements[1],
                       field->nElements[2], grid[0], grid[1], grid[2]);
+
+  if (field->mesh_type == nonuniform)
+    {
+      /* If mesh was already allocated, we free it. */
+      if (field->meshx)
+        g_free(field->meshx);
+
+      if (field->meshy)
+        g_free(field->meshy);
+
+      if (field->meshz)
+        g_free(field->meshz);
+    }
+
   /* If data was already allocated, we free it. */
   if (field->data)
     {
@@ -362,13 +589,25 @@ void scalarFieldSet_gridSize(ScalarField *field, int grid[3])
       	}
       g_free(field->data);
     }
-    
-  /* We change the size and reallocate data. */
+
+  /* We change the size and reallocate mesh and data. */
   field->nElements[0] = grid[0];
   field->nElements[1] = grid[1];
   field->nElements[2] = grid[2];
 
-  DBG_fprintf(stderr, "ScalarField : allocating array.\n");
+  if (field->mesh_type == nonuniform)
+    {
+      DBG_fprintf(stderr, "ScalarField : allocating meshx array.\n");
+      field->meshx = g_malloc(sizeof(double) * grid[0]);
+
+      DBG_fprintf(stderr, "ScalarField : allocating meshy array.\n");
+      field->meshy = g_malloc(sizeof(double) * grid[1]);
+
+      DBG_fprintf(stderr, "ScalarField : allocating meshz array.\n");
+      field->meshz = g_malloc(sizeof(double) * grid[2]);
+    }
+
+  DBG_fprintf(stderr, "ScalarField : allocating data array.\n");
   field->data = g_malloc(sizeof(double **) * grid[0]);
   for(i = 0; i < grid[0]; i++)
     {
@@ -385,6 +624,25 @@ void scalarFieldGet_minMax(ScalarField *field, double minmax[2])
   minmax[0] = field->min;
   minmax[1] = field->max;
 }
+double scalarFieldGet_secondaryMin(ScalarField *field)
+{
+  int i, j, k;
+
+  g_return_val_if_fail(field, 0.);
+  
+  /* In log scale, we need the second minimum value. */
+  if (field->secondMin == G_MAXFLOAT)
+    {
+      for (i = 0; i < field->nElements[0]; i++)
+	for (j = 0; j < field->nElements[1]; j++)
+	  for (k = 0; k < field->nElements[2]; k++)
+	    field->secondMin = (field->data[i][j][k] == field->min)?
+	      field->secondMin:MIN(field->data[i][j][k], field->secondMin);
+      DBG_fprintf(stderr, "Scalar Fields: second minimum is %g (%g < %g).\n",
+		  field->secondMin, field->min, field->max);
+    }
+  return field->secondMin;
+}
 void scalarFieldSet_data(ScalarField *field, double *data)
 {
   int i, j, k, ii;
@@ -405,20 +663,31 @@ void scalarFieldSet_data(ScalarField *field, double *data)
         }
 }
 void scalarFieldDraw_map(ScalarField *field, Plane *plane, Shade *shade,
-                         OpenGLView *view, float precision, float drawnMinMax[2])
+                         OpenGLView *view, float precision, float drawnMinMax[2],
+			 gboolean logScale, guint nIsoLines)
 {
-  float xyz[2][3], normal[3], spherical[3], center[3];
-  float xyzMax[3], dist, Xcoeff, Ycoeff, coeff;
-  float ***values;
-  double value, minmax[2];
+  float xyz[2][3], normal[3], spherical[3], center[3], uMinMax[2], vMinMax[2];
+  float dist, Xcoeff, Ycoeff, coeff, uCoord, vCoord;
+  SurfacesPoints points;
+  double value, minmax[2], minlog;
+  float valMinMax[2];
   GList *inter;
-  int alpha, i, j, k;
-  float rgba[4][4];
-  int posRgba;
-  
+  int alpha, i, j, k, uAlpha[2], vAlpha[2], nU, nV, nPolys, nPoints;
+  int iPolys[4];
+  Line *line;
+  #if DEBUG == 1
+  GTimer *timer;
+  gulong fractionTimer;
+  #endif
+
   g_return_if_fail(field && shade && plane);
   g_return_if_fail(view && precision > 0);
 
+  #if DEBUG == 1
+    timer = g_timer_new();
+    g_timer_start(timer);
+  #endif
+
   planeGet_nVectUser(plane, normal);
   matrix_cartesianToSpherical(spherical, normal);
 
@@ -429,16 +698,6 @@ void scalarFieldDraw_map(ScalarField *field, Plane *plane, Shade *shade,
   if (!inter)
     return;
   
-  dist = 0.;
-  while(inter)
-    {
-      xyzMax[0] = ((float*)inter->data)[0] - center[0];
-      xyzMax[1] = ((float*)inter->data)[1] - center[1];
-      xyzMax[2] = ((float*)inter->data)[2] - center[2];
-      dist = MAX(dist, xyzMax[0] * xyzMax[0] + xyzMax[1] * xyzMax[1] + xyzMax[2] * xyzMax[2]);
-      inter = g_list_next(inter);
-    }
-
   /* We compute the plane basis. */
   xyz[0][0] = cos(spherical[1] * PI180) * cos(spherical[2] * PI180);
   xyz[0][1] = cos(spherical[1] * PI180) * sin(spherical[2] * PI180);
@@ -447,52 +706,142 @@ void scalarFieldDraw_map(ScalarField *field, Plane *plane, Shade *shade,
   xyz[1][1] =  cos(spherical[2] * PI180);
   xyz[1][2] = 0.;
 
-  /* We transform the 3D min and max values in the plane basis. */
-  dist = sqrt(dist);
-  alpha = (int)(20. * (OpenGLViewGet_precision() / 2. + .5) *
+  /* We look for the min and max position in the plane basis for the
+     different intersections. */
+  dist = 0.;
+  uMinMax[0] = 0.;
+  uMinMax[1] = 0.;
+  vMinMax[0] = 0.;
+  vMinMax[1] = 0.;
+  while(inter)
+    {
+      uCoord = xyz[0][0] * (((float*)inter->data)[0] - center[0]) +
+	xyz[0][1] * (((float*)inter->data)[1] - center[1]) +
+	xyz[0][2] * (((float*)inter->data)[2] - center[2]);
+      uMinMax[0] = MIN(uCoord, uMinMax[0]);
+      uMinMax[1] = MAX(uCoord, uMinMax[1]);
+      vCoord = xyz[1][0] * (((float*)inter->data)[0] - center[0]) +
+	xyz[1][1] * (((float*)inter->data)[1] - center[1]) +
+	xyz[1][2] * (((float*)inter->data)[2] - center[2]);
+      vMinMax[0] = MIN(vCoord, vMinMax[0]);
+      vMinMax[1] = MAX(vCoord, vMinMax[1]);
+      inter = g_list_next(inter);
+    }
+  /* So, in plane coordinates, X range in uMinMax and Y in vMinMax. */
+
+  /* We put by default (precision and gross = 1) 30 triangles along
+     the longest line. */
+  alpha = (int)(60. * (OpenGLViewGet_precision() / 2. + .5) *
                 precision * (view->camera->gross / 2. + .5) / 100.);
+  dist = sqrt(view->box->p7[0] * view->box->p7[0] +
+	      view->box->p7[1] * view->box->p7[1] +
+	      view->box->p7[2] * view->box->p7[2]);
+/*   dist = MAX(uMinMax[1] - uMinMax[0], vMinMax[1] - vMinMax[0]); */
+  uAlpha[0] = (int)(uMinMax[0] / dist * (float)alpha) - 1;
+  uAlpha[1] = (int)(uMinMax[1] / dist * (float)alpha) + 2;
+  vAlpha[0] = (int)(vMinMax[0] / dist * (float)alpha * 1.154700538379251448) - 1;
+  vAlpha[1] = (int)(vMinMax[1] / dist * (float)alpha * 1.154700538379251448) + 2;
   scalarFieldGet_minMax(field, minmax);
   drawnMinMax[0] = minmax[1];
   drawnMinMax[1] = minmax[0];
 
-/*   DBG_fprintf(stderr, "Panel Map : storing values.\n"); */
-  values = g_malloc(sizeof(float**) * 2 * alpha);
-  for (i = -alpha; i < alpha; i++)
-    {
-      values[i + alpha] = g_malloc(sizeof(float*) * 2 * alpha);
-      for (j = -alpha; j < alpha; j++)
-	/* The first value if 0 if the point is not used,
-	   the next three are the coordinates,
-	   the fourth is the scalar field value,
-	   and the next 4 values are a storage for RGBA values. */
-	values[i + alpha][j + alpha] = g_malloc(sizeof(float) * 9);
-    }
+  DBG_fprintf(stderr, "Panel Map: allocating storing values (%dx%d).\n",
+	      vAlpha[0] + vAlpha[1], uAlpha[0] + uAlpha[1]);
+  /* We store 6 additional data per point.
+     - 0: used or not ;
+     - 1: field value ;
+     - 2~5: RGBA. */
+  isosurfacesPointsInit(&points, 6);
+  nU = uAlpha[1] - uAlpha[0];
+  nV = vAlpha[1] - vAlpha[0];
+  isosurfacesPointsAllocate(&points, 1, (nV - 1) * (2 * (nU - 1) - 2), nV * nU);
+
+  /* In log scale, we need the second minimum value. */
+  minlog = minmax[0];
+  if (logScale)
+    minlog = scalarFieldGet_secondaryMin(field);
+
   /* We use an hexagonal padding for equilateral triangles. */
-  coeff =  dist / (float)alpha * 1.154700538379251448;
-  for (i = 0; i < 2 * alpha; i++)
+  minlog = log10((minlog - minmax[0]) / (minmax[1] - minmax[0]));
+  coeff =  dist / (float)alpha;
+  nPoints = 0;
+  for (i = 0; i < vAlpha[1] - vAlpha[0]; i++)
     {
-      Ycoeff = (float)(i - alpha) * coeff * 0.8660254; /* the num coef is cos 30 */
-      for (j = 0; j < 2 * alpha; j++)
+      Ycoeff = (float)(i + vAlpha[0]) * coeff * 0.8660254; /* the num coef is cos 30 */
+      for (j = 0; j < uAlpha[1] - uAlpha[0]; j++)
 	{
 	  if (i%2)
-	    Xcoeff = (float)(j - alpha) * coeff;
+	    Xcoeff = (float)(j + uAlpha[0]) * coeff;
 	  else
-	    Xcoeff = ((float)(j - alpha) + 0.5) * coeff;
-	  values[i][j][1] = center[0] + Xcoeff * xyz[0][0] + Ycoeff * xyz[1][0];
-	  values[i][j][2] = center[1] + Xcoeff * xyz[0][1] + Ycoeff * xyz[1][1];
-	  values[i][j][3] = center[2] + Xcoeff * xyz[0][2] + Ycoeff * xyz[1][2];
-	  values[i][j][0] = (float)scalarFieldGet_value(field, &values[i][j][1], &value);
-	  if ((gboolean)values[i][j][0])
+	    Xcoeff = ((float)(j + uAlpha[0]) + 0.5) * coeff;
+	  points.poly_points_data[nPoints][MAP_X] = center[0] +
+	    Xcoeff * xyz[0][0] + Ycoeff * xyz[1][0];
+	  points.poly_points_data[nPoints][MAP_Y] = center[1] +
+	    Xcoeff * xyz[0][1] + Ycoeff * xyz[1][1];
+	  points.poly_points_data[nPoints][MAP_Z] = center[2] +
+	    Xcoeff * xyz[0][2] + Ycoeff * xyz[1][2];
+	  points.poly_points_data[nPoints][MAP_VISIBILITY] =
+	    (float)scalarFieldGet_value(field, points.poly_points_data[nPoints],
+					&value, view->box->extension);
+	  if ((gboolean)points.poly_points_data[nPoints][MAP_VISIBILITY])
 	    {
-	      values[i][j][4] = (float)((value - minmax[0]) / (minmax[1] - minmax[0]));
-	      shadeGet_valueTransformedInRGB(shade, &values[i][j][5], values[i][j][4]);
-	      drawnMinMax[0] =MIN(drawnMinMax[0], (float)value);
-	      drawnMinMax[1] =MAX(drawnMinMax[1], (float)value);
+	      points.poly_points_data[nPoints][MAP_VALUE] =
+		(float)((CLAMP(value, minmax[0], minmax[1]) - minmax[0]) /
+			(minmax[1] - minmax[0]));
+	      if (logScale)
+		points.poly_points_data[nPoints][MAP_VALUE] =
+		  (points.poly_points_data[nPoints][MAP_VALUE] == 0.f)?0.f:
+		  - (log10(points.poly_points_data[nPoints][MAP_VALUE])
+		     - minlog) / minlog;
+	      shadeGet_valueTransformedInRGB
+		(shade,
+		 points.poly_points_data[nPoints] + MAP_R,
+		 points.poly_points_data[nPoints][MAP_VALUE]);
+	      drawnMinMax[0] = MIN(drawnMinMax[0], (float)value);
+	      drawnMinMax[1] = MAX(drawnMinMax[1], (float)value);
 	    }
 /* 	  DBG_fprintf(stderr, " | %d (%g, %g, %g) -> %g\n", (gboolean)values[i][j][0], */
 /* 		      values[i][j][1], values[i][j][2], values[i][j][3], values[i][j][4]); */
+	  nPoints += 1;
 	}
     }
+  nPolys = 0;
+  points.num_polys_surf[0] = 0;
+  for (i = 0; i < vAlpha[1] - vAlpha[0] - 1; i++)
+    {
+      iPolys[3] = 0;
+      for (j = 0; j < uAlpha[1] - uAlpha[0] - 1; j++)
+	{
+	  for (k = 1; k >= 0; k--)
+	    {
+	      iPolys[3] += 1;
+	      iPolys[iPolys[3]%3] = (i + (i + k)%2) * nU + j;
+	      if (iPolys[3] > 2)
+		{
+		  /* The triangle is visible if all of its vertices are
+		     visible. */
+		  if ((gboolean)points.poly_points_data[iPolys[0]][MAP_VISIBILITY] &&
+		      (gboolean)points.poly_points_data[iPolys[1]][MAP_VISIBILITY] &&
+		      (gboolean)points.poly_points_data[iPolys[2]][MAP_VISIBILITY])
+		    {
+		      points.poly_surf_index[nPolys] = 1;
+		      points.num_polys_surf[0]      += 1;
+		    }
+		  else
+		    points.poly_surf_index[nPolys] = -1;
+		  points.poly_num_vertices[nPolys] = 3;
+		  points.poly_vertices[nPolys] = g_malloc(sizeof(int) * 3);
+		  points.poly_vertices[nPolys][0] = iPolys[0];
+		  points.poly_vertices[nPolys][1] = iPolys[1];
+		  points.poly_vertices[nPolys][2] = iPolys[2];
+		  nPolys += 1;
+		}
+	    }
+	}
+    }
+#if DEBUG == 1
+  isosurfacesPointsCheck(&points);
+#endif
 
   glDisable(GL_CULL_FACE);
   glDisable(GL_LIGHTING);
@@ -524,77 +873,137 @@ void scalarFieldDraw_map(ScalarField *field, Plane *plane, Shade *shade,
 /* 	     center[1] - dist * xyz[0][1] - dist * xyz[1][1], */
 /* 	     center[2] - dist * xyz[0][2] - dist * xyz[1][2]); */
 /*   glEnd(); */
-
-  /* The rgba[3][:] are the average color for the last three vertex. */
-  for (i = 0; i < 4; i++)
-    for (j = 0; j < 4; j++)
-      rgba[i][j] = 0.;
-  posRgba = 0;
-  for (i = 0; i < 2 * alpha - 1; i++)
+  for (i = 0; i < points.num_polys; i++)
     {
-      glBegin(GL_TRIANGLE_STRIP);
-      for (j = 0; j < 2 * alpha - 1; j++)
+      if (points.poly_surf_index[i] > 0)
 	{
-	  if ((gboolean)values[i + (i + 1)%2][j][0])
-	    {
-	      for (k = 0; k < 3; k++)
-		{
-		  rgba[3][k] += (values[i + (i + 1)%2][j][5 + k] - rgba[posRgba][k]) / 3.;
-		  rgba[posRgba][k] = values[i + (i + 1)%2][j][5 + k];
-		}
-	      posRgba = (posRgba + 1)%3;
-	      glColor3fv(rgba[3]);
-	      glNormal3fv(normal);
-	      glVertex3fv(&values[i + (i + 1)%2][j][1]);
-	    }
-	  if ((gboolean)values[i + i%2][j][0])
-	    {
-	      for (k = 0; k < 3; k++)
-		{
-		  rgba[3][k] += (values[i + i%2][j][5 + k] - rgba[posRgba][k]) / 3.;
-		  rgba[posRgba][k] = values[i + i%2][j][5 + k];
-		}
-	      posRgba = (posRgba + 1)%3;
-	      glColor3fv(rgba[3]); 
-	      glNormal3fv(normal);
-	      glVertex3fv(&values[i + i%2][j][1]);
-	    }
+	  glBegin(GL_TRIANGLE_STRIP);
+	  glColor3fv(points.poly_points_data[points.poly_vertices[i][0]] + MAP_R);
+	  glVertex3fv(points.poly_points_data[points.poly_vertices[i][0]]);
+	  glColor3fv(points.poly_points_data[points.poly_vertices[i][1]] + MAP_R);
+	  glVertex3fv(points.poly_points_data[points.poly_vertices[i][1]]);
+	  glColor3fv(points.poly_points_data[points.poly_vertices[i][2]] + MAP_R);
+	  glVertex3fv(points.poly_points_data[points.poly_vertices[i][2]]);
+	  glEnd();
 	}
-      glEnd();
     }
-  glPopMatrix();  
-  glEnable(GL_LIGHTING);
-  glEnable(GL_CULL_FACE);
 
-  for (i = 0; i < 2 * alpha; i++)
-    {
-      for (j = 0; j < 2 * alpha; j++)
-	g_free(values[i][j]);
-      g_free(values[i]);
-    }
-  g_free(values);
+  valMinMax[0] =
+    (float)((CLAMP(drawnMinMax[0], minmax[0], minmax[1]) - minmax[0]) /
+	    (minmax[1] - minmax[0]));
+  if (logScale)
+    valMinMax[0] = (valMinMax[0] == 0.f)?0.f:
+      - (log10(valMinMax[0]) - minlog) / minlog;
+  valMinMax[1] =
+    (float)((CLAMP(drawnMinMax[1], minmax[0], minmax[1]) - minmax[0]) /
+	    (minmax[1] - minmax[0]));
+  if (logScale)
+    valMinMax[1] = (valMinMax[1] == 0.f)?0.f:
+      - (log10(valMinMax[1]) - minlog) / minlog;
+  for (i = 1; i <= (int)nIsoLines; i++)
+    if (isolineBuild(&line, &points, MAP_VALUE, MAP_VISIBILITY,
+		     valMinMax[0] + (valMinMax[1] - valMinMax[0]) *
+		     (float)i / (float)(nIsoLines + 1)))
+      {
+	isolineDraw(line);
+	isolineFree(line);
+      }
+
+  glPopMatrix();  
+  glEnable(GL_CULL_FACE);
+  glEnable(GL_LIGHTING);
+
+  isosurfacesPointsFree(&points);
+
+  #if DEBUG == 1
+    g_timer_stop(timer);
+    fprintf(stderr, "ScalarFields : Draw Map in %g micro-s.\n",
+	    g_timer_elapsed(timer, &fractionTimer)/1e-6);
+    g_timer_destroy(timer);
+  #endif
 }
 
-gboolean scalarFieldGet_value(ScalarField *field, float xyz[3], double *value)
+gboolean scalarFieldGet_value(ScalarField *field, float xyz[3],
+			      double *value, float extension[3])
 {
-  float redXyz[3], localXyz[3], pos;
-  int l, ijk[3], dijk[3];
+  float redXyz[3], factor[3], pos;
+  int l, m, n, ijk[3], dijk[3], nMax;
+  int nval1, nval2;
+  double *mesh;
+  ScalarField_meshflag meshtype;
+
+  /* Taken from ABINIT */
+  float x1,x2,x3;
 
   g_return_val_if_fail(field, FALSE);
-  
+
+  meshtype = scalarFieldGet_meshtype(field);
+
   /* First, we transform the coordinates into reduced coordinates. */
   matrix_productVector(redXyz, field->fromXYZtoReducedCoord, xyz);
 
   /* We compute i, j, k. */
   for (l = 0; l < 3; l++)
     {
-      pos = (float)field->nElements[l] * redXyz[l];
-      ijk[l] = (int)pos;
+      /* If we are periodic and inside the extension, we put back in
+	 the box. */
+      if (field->periodic && redXyz[l] > -extension[l] &&
+	  redXyz[l] < 1. + extension[l])
+	redXyz[l] = fModulo(redXyz[l], 1);
+      if (field->periodic)
+	nMax = field->nElements[l];
+      else
+	nMax = field->nElements[l] - 1;
+
+      switch (meshtype)
+        {
+        case uniform:
+          pos = (float)nMax * redXyz[l];
+          ijk[l] = (int)pos;
+          factor[l] = pos - (float)ijk[l];
+          break;
+        case nonuniform:
+	  mesh = (double*)0;
+	  switch (l)
+	    {
+	    case 0:
+	      mesh = scalarFieldGet_meshx(field);
+	      break;
+	    case 1:
+	      mesh = scalarFieldGet_meshy(field);
+	      break;
+	    case 2:
+	      mesh = scalarFieldGet_meshz(field);
+	      break;
+	    }
+          nval1 = 0;
+          nval2 = nMax-1;
+	  n = 0;
+          for (m = 0; m < nMax/2; m++)
+            {
+              n = (int)((nval2-nval1)/2);
+              if (n == 0) {
+                n = nval1;
+                break;    }
+              else
+                n = nval1+n;
+              if (redXyz[l] > mesh[n])
+                nval1 = n;
+              else
+                nval2 = n;
+            }
+          ijk[l] = n;
+          factor[l] = (redXyz[l]-mesh[n])/(mesh[n+1]-mesh[n]);
+          break;
+        default:
+          g_warning("Wrong value for 'meshtype'.");
+          return FALSE;
+        }
+	
       if (ijk[l] < 0 || redXyz[l] < 0.)
 	return FALSE;
-      if (ijk[l] >= field->nElements[l])
+      if (ijk[l] >= nMax)
 	return FALSE;
-      localXyz[l] = pos - (float)ijk[l];
     }
 
   /* We linearly interpolate the value. */
@@ -609,8 +1018,32 @@ gboolean scalarFieldGet_value(ScalarField *field, float xyz[3], double *value)
       else
 	dijk[l] += 1;
       *value += (field->data[dijk[0]][dijk[1]][dijk[2]] -
-		 field->data[ijk[0]][ijk[1]][ijk[2]]) * localXyz[l];
+		 field->data[ijk[0]][ijk[1]][ijk[2]]) * factor[l];
     }
+
+  /* lower left is ijk. */
+  /* upper right is dijk. */
+  dijk[0] = (ijk[0] + 1) % field->nElements[0];
+  dijk[1] = (ijk[1] + 1) % field->nElements[1];
+  dijk[2] = (ijk[2] + 1) % field->nElements[2];
+  
+  /* weight is factor. */
+  x1 = factor[0];
+  x2 = factor[1];
+  x3 = factor[2];
+
+  /* calculation of the density value */
+  *value  = 0.f;
+  *value += field->data[ ijk[0]][ ijk[1]][ ijk[2]] *
+    (1.f - x1) * (1.f - x2) * (1.f - x3);
+  *value += field->data[dijk[0]][ ijk[1]][ ijk[2]] * x1 * (1.f - x2) * (1.f - x3);
+  *value += field->data[ ijk[0]][dijk[1]][ ijk[2]] * (1.f - x1) * x2 * (1.f - x3);
+  *value += field->data[ ijk[0]][ ijk[1]][dijk[2]] * (1.f - x1) * (1.f - x2) * x3;
+  *value += field->data[dijk[0]][dijk[1]][ ijk[2]] * x1 * x2 * (1.f - x3);
+  *value += field->data[ ijk[0]][dijk[1]][dijk[2]] * (1.f  -x1) * x2 * x3;
+  *value += field->data[dijk[0]][ ijk[1]][dijk[2]] * x1 * (1.f - x2) * x3;
+  *value += field->data[dijk[0]][dijk[1]][dijk[2]] * x1 * x2 * x3;
+
   return TRUE;
 }
 void scalarFieldSet_box(ScalarField *field, float box[6])
@@ -619,7 +1052,7 @@ void scalarFieldSet_box(ScalarField *field, float box[6])
 
   g_return_if_fail(field);
 
-  DBG_fprintf(stderr, "ScalarField : set the bouding box.\n");
+  DBG_fprintf(stderr, "ScalarField : set the bounding box.\n");
 
   /* Change the box. */
   for (i = 0; i < 6; i++)
@@ -670,6 +1103,21 @@ void scalarFieldGet_gridSize(ScalarField *field, int grid[3])
   for (i = 0; i < 3; i++)
     grid[i] = field->nElements[i];
 }
+double* scalarFieldGet_meshx(ScalarField *field)
+{
+  g_return_val_if_fail(field, (double*)0);
+  return field->meshx;
+}
+double* scalarFieldGet_meshy(ScalarField *field)
+{
+  g_return_val_if_fail(field, (double*)0);
+  return field->meshy;
+}
+double* scalarFieldGet_meshz(ScalarField *field)
+{
+  g_return_val_if_fail(field, (double*)0);
+  return field->meshz;
+}
 double*** scalarFieldGet_data(ScalarField *field)
 {
   g_return_val_if_fail(field, (double***)0);
