@@ -125,6 +125,8 @@
   " a boolean (0 or 1)"
 #define FLAG_RESOURCE_INTRA "isosurfaces_drawIntra"
 
+static GQuark quark;
+
 typedef struct SurfacesProperties_struct
 {
   /* The element (G_TYPE_INT...). */
@@ -170,7 +172,7 @@ void isosurfacesInit()
 {
   VisuConfigFileEntry *entry;
 
-  VISU_ERROR_ISOSURFACES = g_quark_from_string("visu_isosurfaces");
+  quark = g_quark_from_static_string("visu_isosurfaces");
 
   entry = visuConfigFileAdd_entry(VISU_CONFIGFILE_RESOURCE,
 				  FLAG_RESOURCE_INTRA,
@@ -182,6 +184,10 @@ void isosurfacesInit()
   
   isosurfacesResourcesInit();
 }
+GQuark isosurfacesGet_quark()
+{
+  return quark;
+}
 
 void isosurfacesCheck_consistency(Surfaces* surf)
 {
