@@ -77,7 +77,8 @@ struct SurfacesOrder_struct;
  */
 typedef struct SurfacesOrder_struct SurfacesOrder;
 
-GQuark VISU_ERROR_ISOSURFACES;
+#define VISU_ERROR_ISOSURFACES isosurfacesGet_quark()
+GQuark isosurfacesGet_quark();
 enum
   {
     VISU_ERROR_FORMAT,
