@@ -57,6 +57,7 @@
 
 #include "gtk_colorComboBoxWidget.h"
 #include <visu_tools.h>
+#include <visu_object.h>
 
 /**
  * SECTION:colorcombobox
@@ -277,7 +278,7 @@ static void colorComboBox_class_init(ColorComboBoxClass *klass)
 		     COLUMN_COLOR_LABEL       , _("New / modify"),
 		     COLUMN_COLOR_POINTER_TO  , NULL,
 		     -1);
-  klass->colorAddedSignalId = g_signal_connect(G_OBJECT(visu), "colorNewAvailable",
+  klass->colorAddedSignalId = g_signal_connect(VISU_INSTANCE, "colorNewAvailable",
 					       G_CALLBACK(onNewColorAvailable),
 					       (gpointer)klass);
   DBG_fprintf(stderr, "                     - add stored colours.\n");
@@ -614,9 +615,9 @@ static void colorComboBox_changed(GtkWidget *widget _U_, ColorComboBox *colorCom
       rgba[3] = (float)gtk_color_selection_get_current_alpha(GTK_COLOR_SELECTION(GTK_COLOR_SELECTION_DIALOG(selection)->colorsel)) / 65535.;
 
       klass = G_OBJECT_GET_CLASS(colorComboBox);
-      g_signal_handler_block(G_OBJECT(visu), COLOR_COMBOX_CLASS(klass)->colorAddedSignalId);
+      g_signal_handler_block(VISU_INSTANCE, COLOR_COMBOX_CLASS(klass)->colorAddedSignalId);
       color = colorAdd_floatRGBA(rgba, &selected);
-      g_signal_handler_unblock(G_OBJECT(visu), COLOR_COMBOX_CLASS(klass)->colorAddedSignalId);
+      g_signal_handler_unblock(VISU_INSTANCE, COLOR_COMBOX_CLASS(klass)->colorAddedSignalId);
       addColorToModel(&iter, COLOR_COMBOX_CLASS(klass), color);
       gtk_combo_box_set_active_iter(GTK_COMBO_BOX(colorComboBox), &iter);
     }
@@ -694,9 +695,9 @@ static void colorComboBox_addButtonClicked(GtkButton *button _U_, gpointer data)
 
   rgba = colorComboBoxGet_color(colorComboBox);
   klass = G_OBJECT_GET_CLASS(colorComboBox);
-  g_signal_handler_block(G_OBJECT(visu), COLOR_COMBOX_CLASS(klass)->colorAddedSignalId);
+  g_signal_handler_block(VISU_INSTANCE, COLOR_COMBOX_CLASS(klass)->colorAddedSignalId);
   color = colorAdd_floatRGBA(rgba, &selected);
-  g_signal_handler_unblock(G_OBJECT(visu), COLOR_COMBOX_CLASS(klass)->colorAddedSignalId);
+  g_signal_handler_unblock(VISU_INSTANCE, COLOR_COMBOX_CLASS(klass)->colorAddedSignalId);
   addColorToModel(&iter, COLOR_COMBOX_CLASS(klass), color);
   gtk_combo_box_set_active_iter(GTK_COMBO_BOX(colorComboBox), &iter);
   g_free(rgba);
