@@ -375,7 +375,7 @@ GtkWidget* orientationChooserNew(OrientationChooserKind kind, gboolean liveUpdat
   /* Set other internal values. */
   orientationChooser->kind = kind;
   visuDataChanged(orientationChooser, data);
-  g_signal_connect(G_OBJECT(visu), "dataReadyForRendering",
+  g_signal_connect(VISU_INSTANCE, "dataReadyForRendering",
 		   G_CALLBACK(onDataReadyForRendering), (gpointer)orientationChooser);
 
   return GTK_WIDGET(orientationChooser);
