@@ -109,7 +109,7 @@ void gtkAboutBuild_window(GtkMain *main)
   gtk_widget_set_name(wd, "message_notebook");
 
   /* Create the interior of the tabs. */
-  chemin = g_build_filename(v_sim_legal_dir, V_SIM_LICENCE_FILE, NULL);
+  chemin = g_build_filename(V_SIM_LEGAL_DIR, V_SIM_LICENCE_FILE, NULL);
   buffer = (gchar*)0;
   err = (GError*)0;
   if (!g_file_get_contents(chemin, &buffer, &taille, &err))
@@ -131,7 +131,7 @@ void gtkAboutBuild_window(GtkMain *main)
     }
   g_free(chemin);
 
-  chemin = g_build_filename(v_sim_legal_dir, V_SIM_README_FILE, NULL);
+  chemin = g_build_filename(V_SIM_LEGAL_DIR, V_SIM_README_FILE, NULL);
   buffer = (gchar*)0;
   err = (GError*)0;
   if (!g_file_get_contents(chemin, &buffer, &taille, &err))
@@ -168,7 +168,7 @@ void gtkAboutBuild_window(GtkMain *main)
     }
   g_free(chemin);
 
-  chemin = g_build_filename(v_sim_legal_dir, V_SIM_AUTHORS_FILE, NULL);
+  chemin = g_build_filename(V_SIM_LEGAL_DIR, V_SIM_AUTHORS_FILE, NULL);
   buffer = (gchar*)0;
   err = (GError*)0;
   if (!g_file_get_contents(chemin, &buffer, &taille, &err))
