@@ -59,7 +59,8 @@
 static GtkInteractiveActionId currentAction;
 
 /* Callbacks. */
-static void onNewData(GObject *obj, VisuData *dataObj, gpointer bool);
+static void onNewData(GObject *obj, VisuData *dataObj, gpointer data);
+static void onVisuData(GObject *obj, VisuData *dataObj, gpointer data);
 static void observeMethodChanged(GtkToggleButton* button, gpointer data);
 static void radioObserveToggled(GtkToggleButton *togglebutton, gpointer user_data);
 static void radioPickToggled(GtkToggleButton *togglebutton, gpointer user_data);
@@ -253,9 +254,13 @@ void gtkInteractiveInit_session()
 
 static void onCloseButtonClicked(GtkButton *button _U_, gpointer user_data _U_)
 {
+  if (!GTK_WIDGET_VISIBLE(observeWindow))
+    return;
+
+  DBG_fprintf(stderr, "Gtk interactive: click on close button.\n");
+
   gtkPick_onClose();
 
-  DBG_fprintf(stderr, "Gtk observePick: click on close button.\n");
   flagDisableChangePickObserve = TRUE;
   openGLInteractiveEnd_session((VisuInteractive*)g_object_get_data
 			       (G_OBJECT(observeWindow), "visuInteractive_data"));
@@ -310,12 +315,14 @@ static void connectSignalsObservePick()
 {
   GtkWidget *wd;
 
-  g_signal_connect(G_OBJECT(visu), "dataNew",
+  g_signal_connect(VISU_INSTANCE, "dataNew",
 		   G_CALLBACK(onNewData), (gpointer)0);
 
   wd = lookup_widget(observeWindow, "buttonBackToCommandPanel");
   g_signal_connect(G_OBJECT(wd), "clicked",
 		   G_CALLBACK(onCloseButtonClicked), (gpointer)0);
+  g_signal_connect(VISU_INSTANCE, "dataReadyForRendering",
+		   G_CALLBACK(onVisuData), (gpointer)wd);
   wd = lookup_widget(observeWindow, "radioObserve");
   g_signal_connect(G_OBJECT(wd), "toggled",
 		   G_CALLBACK(radioObserveToggled), (gpointer)0);
@@ -382,6 +389,11 @@ static void onNewData(GObject *obj _U_, VisuData *dataObj, gpointer data _U_)
   g_signal_connect(G_OBJECT(dataObj), "OpenGLPersp",
 		   G_CALLBACK(refreshCameraSpinValues), (gpointer)0);
 }
+static void onVisuData(GObject *obj _U_, VisuData *dataObj, gpointer data)
+{
+  if (!dataObj)
+    gtk_button_clicked(GTK_BUTTON(data));
+}
 
 static void observeMethodChanged(GtkToggleButton* button, gpointer data)
 {
