@@ -66,7 +66,6 @@
 #include "panelModules/panelBrowser.h"
 #include "panelModules/panelDataFile.h"
 #include "panelModules/panelPlanes.h"
-#include "panelModules/panelSurfaces.h"
 #include "panelModules/gtkAtomic.h"
 #include "panelModules/gtkSpin.h"
 
@@ -308,7 +307,7 @@ static void gtkMainClass_init(GtkMainClass *klass)
 				   exportParametersGtkMain);
 
   /* Set the pixmap directory for the Glade stuff. */
-  add_pixmap_directory(v_sim_pixmaps_dir);
+  add_pixmap_directory(V_SIM_PIXMAPS_DIR);
 
   /* Set static parameters. */
   klass->rememberWindowPosition = PARAMETER_GTKMAIN_REMEMBER_DEFAULT;
@@ -483,11 +482,11 @@ static void gtkMain_init(GtkMain *obj)
 		   G_CALLBACK(onKillMainWindowEvent), (gpointer)0);
   g_signal_connect(G_OBJECT(obj), "destroy-event",
 		   G_CALLBACK(onKillMainWindowEvent), (gpointer)0);
-  g_signal_connect_swapped(G_OBJECT(visu), "resourcesLoaded",
+  g_signal_connect_swapped(VISU_INSTANCE, "resourcesLoaded",
 			   G_CALLBACK(onResourcesLoaded), (gpointer)obj);
-  g_signal_connect_swapped(G_OBJECT(visu), "dataReadyForRendering", 
+  g_signal_connect_swapped(VISU_INSTANCE, "dataReadyForRendering", 
 			   G_CALLBACK(onFileChange), (gpointer)obj);
-  g_signal_connect_swapped(G_OBJECT(visu), "renderingChanged",
+  g_signal_connect_swapped(VISU_INSTANCE, "renderingChanged",
 			   G_CALLBACK(onRenderingChanged), (gpointer)obj);
 
   DBG_fprintf(stderr, " ... OK.\n");
@@ -875,16 +874,22 @@ static void onAddHomedir(GtkButton *button _U_, gpointer quitDialog)
   GtkWidget *wd;
   GList *dirs, *tmplst;
   gchar *path;
+#if SYSTEM_X11 == 1
+#define PERMS (S_IRWXU | S_IRGRP | S_IXGRP)
+#endif
+#if SYSTEM_WIN32 == 1
+#define PERMS 0
+#endif
 
   DBG_fprintf(stderr, "Gtk Main: try to create the local home directory.\n");
 #if GLIB_MINOR_VERSION > 7
-  if (g_mkdir_with_parents(v_sim_local_conf_dir, 750))
+  if (g_mkdir_with_parents(V_SIM_LOCAL_CONF_DIR, PERMS))
 #else
 #if SYSTEM_X11 == 1
-  if (mkdir(v_sim_local_conf_dir, 750))
+  if (mkdir(V_SIM_LOCAL_CONF_DIR, PERMS))
 #endif
 #if SYSTEM_WIN32 == 1
-  if (mkdir(v_sim_local_conf_dir))
+  if (mkdir(V_SIM_LOCAL_CONF_DIR))
 #endif
 #endif
     /* Failed. */
@@ -898,8 +903,8 @@ static void onAddHomedir(GtkButton *button _U_, gpointer quitDialog)
       gtk_widget_hide(wd);
       /* Retest the path. */
       dirs = (GList*)0;
-      dirs = g_list_prepend(dirs, (gpointer)v_sim_data_dir);
-      dirs = g_list_prepend(dirs, (gpointer)v_sim_local_conf_dir);
+      dirs = g_list_prepend(dirs, (gpointer)V_SIM_DATA_DIR);
+      dirs = g_list_prepend(dirs, (gpointer)V_SIM_LOCAL_CONF_DIR);
       tmplst = dirs;
 
       path = (gchar*)0;
@@ -936,8 +941,8 @@ void gtkMain_quit()
      that is writable to store the preference of the hiding
      mode of the dialog. */
   dirs = (GList*)0;
-  dirs = g_list_prepend(dirs, (gpointer)v_sim_data_dir);
-  dirs = g_list_prepend(dirs, (gpointer)v_sim_local_conf_dir);
+  dirs = g_list_prepend(dirs, (gpointer)V_SIM_DATA_DIR);
+  dirs = g_list_prepend(dirs, (gpointer)V_SIM_LOCAL_CONF_DIR);
   tmplst = dirs;
 
   path = (gchar*)0;
@@ -954,7 +959,7 @@ void gtkMain_quit()
   g_signal_connect(G_OBJECT(wd), "clicked",
 		   G_CALLBACK(onAddHomedir), (gpointer)quitDialog);
   /* Show the warning if the homedir is not existing and no path was found. */
-  if (!g_file_test(v_sim_local_conf_dir, G_FILE_TEST_IS_DIR) && !path)
+  if (!g_file_test(V_SIM_LOCAL_CONF_DIR, G_FILE_TEST_IS_DIR) && !path)
     {
       wd = lookup_widget(quitDialog, "hboxHomedir");
       gtk_widget_show(wd);
