@@ -65,6 +65,8 @@ static void onMoveToOriginalClicked(GtkButton *button, gpointer data);
 static void onRemoveNodeClicked(GtkButton *button, gpointer user_data);
 static void onAddNodeClicked(GtkButton *button, gpointer user_data);
 static void onMoveMethod(GtkToggleButton *toggle, gpointer data);
+static void onPageEnter(GtkNotebook *notebook, GtkNotebookPage *page,
+			guint page_num, gpointer user_data);
 
 /* Pick informations hook */
 static int movedNode = -1;
@@ -111,6 +113,8 @@ void gtkMoveBuild_interface(GtkMain *main)
   observeWindow = main->interactiveDialog;
 
   notebookAction = lookup_widget(main->interactiveDialog, "notebookAction");
+  g_signal_connect(G_OBJECT(notebookAction), "switch-page",
+		   G_CALLBACK(onPageEnter), (gpointer)0);
 
   labelMoveId = lookup_widget(main->interactiveDialog, "labelMoveId");
   gtk_label_set_markup(GTK_LABEL(labelMoveId), GTK_MOVE_NO_NODE);
@@ -183,9 +187,9 @@ void gtkMoveBuild_interface(GtkMain *main)
     }
   gtk_combo_box_set_active(GTK_COMBO_BOX(comboElements), 0);
 
-  g_signal_connect(G_OBJECT(visu), "dataReadyForRendering",
+  g_signal_connect(VISU_INSTANCE, "dataReadyForRendering",
 		   G_CALLBACK(onDataReady), (gpointer)0);
-  g_signal_connect(G_OBJECT(visu), "dataNew",
+  g_signal_connect(VISU_INSTANCE, "dataNew",
 		   G_CALLBACK(onNewData), (gpointer)0);
 
   g_signal_connect(G_OBJECT(entryMoveXYZ[0]), "value-changed",
@@ -358,6 +362,21 @@ void gtkMoveUpdate_informations(PickMesure *pickMesure)
 /* Private part */
 /****************/
 
+static void onPageEnter(GtkNotebook *notebook _U_, GtkNotebookPage *page _U_,
+			guint page_num, gpointer user_data _U_)
+{
+  gchar numero[256];
+  GList *lst;
+
+  if (page_num != 1)
+    return;
+
+  lst = gtkPickGet_nodeSelection();
+  sprintf(numero, _("%d node(s)"), g_list_length(lst));
+  gtk_label_set_markup(GTK_LABEL(labelNMoves), numero);
+  g_list_free(lst);
+}
+
 static void onNewData(GObject *obj _U_, VisuData *dataObj, gpointer data _U_)
 {
   g_signal_connect(G_OBJECT(dataObj), "OpenGLThetaPhiOmega",
@@ -532,8 +551,7 @@ static void onMoveToOriginalClicked(GtkButton *button _U_, gpointer data _U_)
     }
   visuDataEmit_nodePositionChanged(dataObj);
 
-  g_signal_emit (visu, VISU_GET_CLASS (visu)->OpenGLAskForReDraw_signal_id,
-		 0 , NULL);
+  g_idle_add(visuObjectRedraw, (gpointer)0);
 }
 static void onRemoveNodeClicked(GtkButton *button _U_, gpointer user_data _U_)
 {
