@@ -464,6 +464,16 @@ guchar* openGLWidgetGet_pixmapData(OpenGLWidget *render, int *width,
   
   /* We create a pixmap context and make this context current. */
   dumpData = visuOpenGLNew_pixmapContext((guint)*width, (guint)*height);
+  if (!dumpData)
+    {
+      /* Switch back to on-screen copy. */
+      g_warning("can't create off-screen pixmap, will screenshot"
+		" the rendering area instead. Make sure that it is"
+		" free of any other windows.");
+      *width = wd->allocation.width;
+      *height = wd->allocation.height;
+      return visuOpenGLGet_pixmapData(*width, *height, hasAlpha);
+    }
   /* We set the glViewport of this new context. */
   glViewport(0, 0, *width, *height);
   /* We call the given draw method. */
