@@ -125,6 +125,8 @@ static void minMaxChanged(GtkSpinButton *spin, GtkTreeSelection *tree, int minMa
 static void addPairAllData(GtkPairsGetValuesAsLabelFunc labelFunc,
 			   VisuElement *ele1, VisuElement *ele2);
 static GtkPairsGetValuesAsLabelFunc getLabelFunc();
+static gint sortPairs(GtkTreeModel *model, GtkTreeIter *a,
+		      GtkTreeIter *b, gpointer user_data);
 
 /* Callbacks. */
 static void onGtkPairsDrawnToggled(GtkCellRendererToggle *cell_renderer,
@@ -133,6 +135,7 @@ static void onDistanceValueEdited(GtkCellRendererText *cellrenderertext,
 				  gchar *path, gchar *text, gpointer user_data);
 static void onGtkPairsLengthToggled(GtkCellRendererToggle *cell_renderer,
 				    gchar *path, gpointer user_data);
+/* static void onSortIndicator(GtkTreeViewColumn *treeviewcolumn, gpointer user_data); */
 static void selectionChanged(GtkTreeSelection *tree, gpointer data);
 static void minChanged(GtkSpinButton *spin, gpointer userData);
 static void maxChanged(GtkSpinButton *spin, gpointer userData);
@@ -213,6 +216,7 @@ void gtkPairsBuild_window(GtkMain *main)
   struct specBuildFunc_struct *specBuild;
   char* markup;
   GtkTooltips *tooltips;
+  GtkTreeSelection *sel;
 
   tooltips = gtk_tooltips_new ();
 
@@ -263,6 +267,14 @@ void gtkPairsBuild_window(GtkMain *main)
   /* Create a filter for the treeview. */
   pairsFilter = gtk_tree_model_filter_new(GTK_TREE_MODEL(pairsTreeStore), NULL);
   pairsSortable = gtk_tree_model_sort_new_with_model(GTK_TREE_MODEL(pairsFilter));
+  gtk_tree_sortable_set_sort_func(GTK_TREE_SORTABLE(pairsSortable),
+				  GTK_PAIRS_COLUMN_LABEL_ELE1, sortPairs,
+				  GINT_TO_POINTER(GTK_PAIRS_COLUMN_LABEL_ELE1),
+				  NULL);
+  gtk_tree_sortable_set_sort_func(GTK_TREE_SORTABLE(pairsSortable),
+				  GTK_PAIRS_COLUMN_LABEL_ELE2, sortPairs,
+				  GINT_TO_POINTER(GTK_PAIRS_COLUMN_LABEL_ELE2),
+				  NULL);
 
   /* Set parameters for the tree */
   gtk_tree_selection_set_mode(gtk_tree_view_get_selection(GTK_TREE_VIEW(gtkPairs_treeView)),
@@ -361,12 +373,20 @@ void gtkPairsBuild_window(GtkMain *main)
 						     NULL);
   gtk_tree_view_column_set_sort_column_id(column, GTK_PAIRS_COLUMN_LABEL_ELE1);
   gtk_tree_view_column_set_sort_indicator(column, TRUE);
+/*   gtk_tree_view_column_set_clickable(column, TRUE); */
+/*   g_signal_connect(G_OBJECT(column), "clicked", */
+/* 		   G_CALLBACK(onSortIndicator), */
+/* 		   GINT_TO_POINTER(GTK_PAIRS_COLUMN_LABEL_ELE1)); */
   gtk_tree_view_append_column(GTK_TREE_VIEW(gtkPairs_treeView), column);
   renderer = gtk_cell_renderer_text_new ();
   column = gtk_tree_view_column_new_with_attributes (_("Ele."), renderer,
 						     "text", GTK_PAIRS_COLUMN_LABEL_ELE2,
 						     NULL);
   gtk_tree_view_column_set_sort_column_id(column, GTK_PAIRS_COLUMN_LABEL_ELE2);
+/*   gtk_tree_view_column_set_clickable(column, TRUE); */
+/*   g_signal_connect(G_OBJECT(column), "clicked", */
+/* 		   G_CALLBACK(onSortIndicator), */
+/* 		   GINT_TO_POINTER(GTK_PAIRS_COLUMN_LABEL_ELE2)); */
   gtk_tree_view_append_column(GTK_TREE_VIEW(gtkPairs_treeView), column);
 
   renderer = gtk_cell_renderer_toggle_new ();
@@ -466,23 +486,24 @@ void gtkPairsBuild_window(GtkMain *main)
   
 
   /* Connect local signals. */
-  g_signal_connect(G_OBJECT(gtk_tree_view_get_selection(GTK_TREE_VIEW(gtkPairs_treeView))),
-		   "changed", G_CALLBACK(selectionChanged), (gpointer)0);
+  sel = gtk_tree_view_get_selection(GTK_TREE_VIEW(gtkPairs_treeView));
+  g_signal_connect(G_OBJECT(sel), "changed",
+		   G_CALLBACK(selectionChanged), (gpointer)0);
   widgetColorSignalId = g_signal_connect(G_OBJECT(widgetColor), "color-selected",
 					 G_CALLBACK(colorChanged), (gpointer)0);
-  gtkPairs_spinMinSignalId = g_signal_connect(G_OBJECT(gtkPairs_spinMin), "value_changed",
-					      G_CALLBACK(minChanged),
-					      (gpointer)gtk_tree_view_get_selection(GTK_TREE_VIEW(gtkPairs_treeView)));
-  gtkPairs_spinMaxSignalId = g_signal_connect(G_OBJECT(gtkPairs_spinMax), "value_changed",
-					      G_CALLBACK(maxChanged),
-					      (gpointer)gtk_tree_view_get_selection(GTK_TREE_VIEW(gtkPairs_treeView)));
+  gtkPairs_spinMinSignalId =
+    g_signal_connect(G_OBJECT(gtkPairs_spinMin), "value_changed",
+		     G_CALLBACK(minChanged), (gpointer)sel);
+  gtkPairs_spinMaxSignalId =
+    g_signal_connect(G_OBJECT(gtkPairs_spinMax), "value_changed",
+		     G_CALLBACK(maxChanged), (gpointer)sel);
 
   /* Set the flag that indicates that interior is not built yet. */
   pairsNeedBuild = TRUE;
 
-  g_signal_connect(G_OBJECT(visu), "dataReadyForRendering",
+  g_signal_connect(VISU_INSTANCE, "dataReadyForRendering",
 		   G_CALLBACK(onDataReady), (gpointer)main);
-  g_signal_connect(G_OBJECT(visu), "resourcesLoaded",
+  g_signal_connect(VISU_INSTANCE, "resourcesLoaded",
 		   G_CALLBACK(rebuildPairsOnResources), (gpointer)main);
 
   DBG_fprintf(stderr, "Gtk Pairs : Pairs are first built.\n");
@@ -579,6 +600,37 @@ static GtkPairsGetValuesAsLabelFunc getLabelFunc()
     return (GtkPairsGetValuesAsLabelFunc)0;
 }
 
+static gint sortPairs(GtkTreeModel *model, GtkTreeIter *a,
+		      GtkTreeIter *b, gpointer colId)
+{
+  gchar *a_ele1, *a_ele2;
+  gchar *b_ele1, *b_ele2;
+  int cmp1, cmp2;
+  
+  gtk_tree_model_get(model, a,
+		     GTK_PAIRS_COLUMN_LABEL_ELE1, &a_ele1,
+		     GTK_PAIRS_COLUMN_LABEL_ELE2, &a_ele2,
+		     -1);
+  gtk_tree_model_get(model, b,
+		     GTK_PAIRS_COLUMN_LABEL_ELE1, &b_ele1,
+		     GTK_PAIRS_COLUMN_LABEL_ELE2, &b_ele2,
+		     -1);
+  DBG_fprintf(stderr, "Gtk Pairs: sort '%s - %s' with '%s - %s' column %d.\n",
+	      a_ele1, a_ele2, b_ele1, b_ele2, GPOINTER_TO_INT(colId));
+  cmp1 = strcmp(a_ele1, b_ele1);
+  cmp2 = strcmp(a_ele2, b_ele2);
+
+  g_free(a_ele1);
+  g_free(a_ele2);
+  g_free(b_ele1);
+  g_free(b_ele2);
+
+  if (GPOINTER_TO_INT(colId) == GTK_PAIRS_COLUMN_LABEL_ELE1)
+    return (cmp1 == 0)?cmp2:cmp1;
+  else
+    return (cmp2 == 0)?cmp1:cmp2;
+}
+
 void gtkPairsBuild_pairs(GtkMain *main, VisuData *dataObj, gboolean force)
 {
   gboolean visible;
@@ -717,7 +769,7 @@ void gtkPairsIter_startSelected(GtkPairsIter *iter)
 void gtkPairsIter_nextSelected(GtkPairsIter *iter)
 {
   gboolean validIter;
-  GtkTreeIter iterFilter;
+  GtkTreeIter iterFilter, iterSort;
 
   g_return_if_fail(iter && iter->selected);
 
@@ -729,7 +781,7 @@ void gtkPairsIter_nextSelected(GtkPairsIter *iter)
       return;
     }
 
-  validIter = gtk_tree_model_get_iter(GTK_TREE_MODEL(pairsFilter), &iterFilter,
+  validIter = gtk_tree_model_get_iter(GTK_TREE_MODEL(pairsSortable), &iterSort,
 				      (GtkTreePath*)iter->current->data);
   gtk_tree_path_free((GtkTreePath*)iter->current->data);
   if (!validIter)
@@ -737,6 +789,8 @@ void gtkPairsIter_nextSelected(GtkPairsIter *iter)
       g_warning("Wrong 'path' variable in 'gtkPairsIter_startSelected' method.\n");
       return;
     }
+  gtk_tree_model_sort_convert_iter_to_child_iter
+    (GTK_TREE_MODEL_SORT(pairsSortable), &iterFilter, &iterSort);
   gtk_tree_model_filter_convert_iter_to_child_iter
     (GTK_TREE_MODEL_FILTER(pairsFilter), &(iter->iter), &iterFilter);
 
@@ -897,14 +951,16 @@ static void onGtkPairsDrawnToggled(GtkCellRendererToggle *cell_renderer _U_,
 				   gchar *path, gpointer user_data _U_)
 {
   gboolean valid, drawn;
-  GtkTreeIter iter, iterFilter;
+  GtkTreeIter iter, iterFilter, iterSort;
   gboolean res;
   VisuPairData *pdata;
 
-  valid = gtk_tree_model_get_iter_from_string(GTK_TREE_MODEL(pairsFilter),
-					      &iterFilter, path);
+  valid = gtk_tree_model_get_iter_from_string(GTK_TREE_MODEL(pairsSortable),
+					      &iterSort, path);
   g_return_if_fail(valid);
 
+  gtk_tree_model_sort_convert_iter_to_child_iter
+    (GTK_TREE_MODEL_SORT(pairsSortable), &iterFilter, &iterSort);
   gtk_tree_model_filter_convert_iter_to_child_iter
     (GTK_TREE_MODEL_FILTER(pairsFilter), &iter, &iterFilter);
   gtk_tree_model_get(GTK_TREE_MODEL(pairsTreeStore), &iter,
@@ -923,14 +979,16 @@ static void onGtkPairsLengthToggled(GtkCellRendererToggle *cell_renderer _U_,
 				    gchar *path, gpointer user_data _U_)
 {
   gboolean valid, length;
-  GtkTreeIter iter, iterFilter;
+  GtkTreeIter iter, iterFilter, iterSort;
   gboolean res;
   VisuPairData *pdata;
 
-  valid = gtk_tree_model_get_iter_from_string(GTK_TREE_MODEL(pairsFilter),
-					      &iterFilter, path);
+  valid = gtk_tree_model_get_iter_from_string(GTK_TREE_MODEL(pairsSortable),
+					      &iterSort, path);
   g_return_if_fail(valid);
 
+  gtk_tree_model_sort_convert_iter_to_child_iter
+    (GTK_TREE_MODEL_SORT(pairsSortable), &iterFilter, &iterSort);
   gtk_tree_model_filter_convert_iter_to_child_iter
     (GTK_TREE_MODEL_FILTER(pairsFilter), &iter, &iterFilter);
   gtk_tree_model_get(GTK_TREE_MODEL(pairsTreeStore), &iter,
@@ -949,7 +1007,7 @@ static void onDistanceValueEdited(GtkCellRendererText *cellrenderertext _U_,
 				  gchar *path, gchar *text, gpointer user_data)
 {
   gboolean valid;
-  GtkTreeIter iter;
+  GtkTreeIter iter, iterFilter, iterSort;
   float value;
   char *error;
   VisuPairData *pdata;
@@ -961,13 +1019,17 @@ static void onDistanceValueEdited(GtkCellRendererText *cellrenderertext _U_,
   g_return_if_fail(GPOINTER_TO_INT(user_data) == GTK_PAIRS_COLUMN_DISTANCE_FROM ||
 		   GPOINTER_TO_INT(user_data) == GTK_PAIRS_COLUMN_DISTANCE_TO);
 
-  valid = gtk_tree_model_get_iter_from_string(GTK_TREE_MODEL(pairsTreeStore),
-					      &iter, path);
-  g_return_if_fail(valid);
-  
   value = (float)strtod(text, &error);
   g_return_if_fail(!(value == 0. && error == text));
 
+  valid = gtk_tree_model_get_iter_from_string(GTK_TREE_MODEL(pairsSortable),
+					      &iterSort, path);
+  g_return_if_fail(valid);
+  gtk_tree_model_sort_convert_iter_to_child_iter
+    (GTK_TREE_MODEL_SORT(pairsSortable), &iterFilter, &iterSort);
+  gtk_tree_model_filter_convert_iter_to_child_iter
+    (GTK_TREE_MODEL_FILTER(pairsFilter), &iter, &iterFilter);
+  
   gtk_tree_store_set(pairsTreeStore, &iter,
 		     GPOINTER_TO_INT(user_data), value,
 		     -1);
@@ -978,6 +1040,7 @@ static void onDistanceValueEdited(GtkCellRendererText *cellrenderertext _U_,
   id = (GPOINTER_TO_INT(user_data) == GTK_PAIRS_COLUMN_DISTANCE_TO)?
     PAIRS_MAX:PAIRS_MIN;
   res = visuPairSet_distance(pdata, value, id);
+
   if (GPOINTER_TO_INT(user_data) == GTK_PAIRS_COLUMN_DISTANCE_FROM)
     gtk_spin_button_set_value(GTK_SPIN_BUTTON(gtkPairs_spinMin), value);
   else
@@ -1005,6 +1068,28 @@ static void minMaxChanged(GtkSpinButton *spin, GtkTreeSelection *tree _U_, int m
   if (res)
     gtkPairs_createPairs();
 }
+/* static void onSortIndicator(GtkTreeViewColumn *column, gpointer colId) */
+/* { */
+/*   GtkSortType sort; */
+/*   GList *cols, *tmpLst; */
+
+/*   tmpLst = cols = gtk_tree_view_get_columns(GTK_TREE_VIEW(gtkPairs_treeView)); */
+/*   while (tmpLst) */
+/*     { */
+/*       gtk_tree_view_column_set_sort_indicator */
+/* 	((GtkTreeViewColumn*)tmpLst->data, FALSE); */
+/*       tmpLst = g_list_next(tmpLst); */
+/*     } */
+/*   g_list_free(cols); */
+
+/*   sort = (gtk_tree_view_column_get_sort_order(column) == GTK_SORT_ASCENDING)? */
+/*     GTK_SORT_DESCENDING:GTK_SORT_ASCENDING; */
+    
+/*   gtk_tree_sortable_set_sort_column_id(GTK_TREE_SORTABLE(pairsTreeStore), */
+/* 				       GPOINTER_TO_INT(colId), sort); */
+/*   gtk_tree_view_column_set_sort_indicator(column, TRUE); */
+/*   gtk_tree_view_column_set_sort_order(column, sort); */
+/* } */
 static void selectionChanged(GtkTreeSelection *tree _U_, gpointer data _U_)
 {
   gboolean select, isChild, hasChild;
