@@ -295,7 +295,7 @@ void gtkPickBuild_interface(GtkMain *main)
   g_signal_connect(G_OBJECT(wd), "clicked",
 		   G_CALLBACK(onEraseDistanceClicked), (gpointer)0);
 
-  g_signal_connect(G_OBJECT(visu), "dataReadyForRendering",
+  g_signal_connect(VISU_INSTANCE, "dataReadyForRendering",
 		   G_CALLBACK(onVisuDataChanged), (gpointer)0);
 
   if (dataObj)
@@ -407,7 +407,7 @@ static void populateComboInfos(VisuData *dataObj)
   GtkTreeIter iter;
   GList *tmpLst;
   gint i, n;
-  gboolean visibility;
+  gboolean visibility, set;
 
   DBG_fprintf(stderr, "Gtk Pick: rebuild the data combo list.\n");
 
@@ -460,7 +460,9 @@ static void populateComboInfos(VisuData *dataObj)
 		   NULL);
       i += 1;
     }
-  gtk_combo_box_set_active(GTK_COMBO_BOX(comboDraw), (n < 0)?0:n);
+  set = (n >= 0 && n < gtk_tree_model_iter_n_children(GTK_TREE_MODEL(listComboInfos),
+						      (GtkTreeIter*)0));
+  gtk_combo_box_set_active(GTK_COMBO_BOX(comboDraw), (set)?n:0);
 }
 static gboolean addNodeAtIter(VisuNode *node, GtkTreeIter *iter)
 {
@@ -787,6 +789,9 @@ static void onVisuDataChanged(GObject *obj _U_, VisuData *dataObj, gpointer data
       g_signal_connect(G_OBJECT(dataObj), "NodePopulationDecrease",
 		       G_CALLBACK(onNodeRemoved), (gpointer)0);
 
+      /* Rebuild the combo of properties. */
+      populateComboInfos(dataObj);
+
       /* Try to match the selected nodes to new ones in the new visuData. */
       valid = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(listDataNode), &iter);
       while (valid)
@@ -808,9 +813,6 @@ static void onVisuDataChanged(GObject *obj _U_, VisuData *dataObj, gpointer data
 	  if (removed)
 	    gtk_list_store_remove(listDataNode, &removedIter);
 	}
-
-      /* Rebuild the combo of properties. */
-      populateComboInfos(dataObj);
     }
   else
     {
