@@ -341,9 +341,9 @@ GtkWidget* renderingWindow_new(char* windowRef, char* window_name,
   renderingWindow->interactiveModeIsBlocked = FALSE;
   renderingWindow->inter = (VisuInteractive*)0;
 
-  g_signal_connect_swapped(G_OBJECT(visu), "OpenGLAskForReDraw",
+  g_signal_connect_swapped(VISU_INSTANCE, "OpenGLAskForReDraw",
 			   G_CALLBACK(onRedraw), (gpointer)renderingWindow);
-  g_signal_connect_swapped(G_OBJECT(visu), "OpenGLForceReDraw",
+  g_signal_connect_swapped(VISU_INSTANCE, "OpenGLForceReDraw",
 			   G_CALLBACK(onForceRedraw), (gpointer)renderingWindow);
 
   DBG_fprintf(stderr, "Gtk RenderingWindow: Building OK.\n");
@@ -481,7 +481,7 @@ GtkInfoArea *gtkStatusInfo_createBar(RenderingWindow *window, gint width, gint h
   info->statusInfoId = gtk_statusbar_get_context_id(GTK_STATUSBAR(info->statusInfo),
 						    "OpenGL statusbar.");
   
-  g_signal_connect_swapped(G_OBJECT(visu), "renderingChanged",
+  g_signal_connect_swapped(VISU_INSTANCE, "renderingChanged",
 			   G_CALLBACK(onRenderingMethodChanged), (gpointer)window);
 
   return info;
@@ -1009,7 +1009,7 @@ void renderingWindowStart_defaultIneractiveMode(RenderingWindow *window)
 {
   VisuInteractive *inter;
 
-  g_return_if_fail(IS_RENDERING_WINDOW(window));
+  g_return_if_fail(IS_RENDERING_WINDOW(window) && window->currentData);
 
   if (window->interactiveModeIsBlocked)
     return;
@@ -1059,7 +1059,12 @@ void renderingWindowUnblock_defaultIneractiveMode(RenderingWindow *window)
   g_return_if_fail(IS_RENDERING_WINDOW(window));
 
   window->interactiveModeIsBlocked = FALSE;
-  renderingWindowStart_defaultIneractiveMode(window);
+  DBG_fprintf(stderr, "Gtk RenderingWindow: start default listener (%p).\n",
+	      (gpointer)window->currentData);
+  if (window->currentData)
+    renderingWindowStart_defaultIneractiveMode(window);
+  else
+    window->interactiveModeIsActive = FALSE;
 }
 void renderingWindowSet_interactiveHandlers(RenderingWindow *window,
 					    VisuInteractive *inter)
@@ -1202,7 +1207,8 @@ void renderingWindowSet_visuData(RenderingWindow *window, VisuData* data)
   if (!noEmit)
     {
       DBG_fprintf(stderr, "Gtk renderingWindow: emitting the 'dataReadyForRendering' signal.\n");
-      g_signal_emit(visu, VISU_GET_CLASS (visu)->dataReadyForRendering_signal_id,
+      g_signal_emit(VISU_INSTANCE,
+		    VISU_GET_CLASS(VISU_INSTANCE)->dataReadyForRendering_signal_id,
 		    0 /* details */, (gpointer)data, NULL);
       DBG_fprintf(stderr, "Gtk renderingWindow: emition done.\n");
     }
@@ -1302,8 +1308,7 @@ void onFileInfoToggled(GtkToggleButton *button, gpointer data)
 
   gtkStatusInfo_setOpenGLSize(window->info, w, h);
 
-  g_signal_emit(visu, VISU_GET_CLASS(visu)->OpenGLForceReDraw_signal_id,
-		0 , NULL);
+  g_idle_add(visuObjectRedraw, (gpointer)0);
 }
 
 void displayFileInfoOnDataLoaded(RenderingWindow *window)
