@@ -896,6 +896,12 @@ static GList* getSelectElementsRegion(VisuData *dataObj, int x1, int y1,
  
    g_return_val_if_fail(IS_VISU_DATA_TYPE(dataObj), (GList*)0);
 
+   DBG_fprintf(stderr, "Interactive: get elements in region %dx%d - %dx%d.\n",
+	       x1, x2, y1, y2);
+
+   if ((x1 == x2) || (y1 == y2))
+     return (GList*)0;
+
    view = visuDataGet_openGLView(dataObj);
 
    bufsize = visuDataGet_nodeArray(dataObj)->nbOfAllStoredNodes * 4;
