@@ -997,7 +997,7 @@ void openGLViewRotate_camera(OpenGLView *view, float dTheta, float dPhi, float a
   matrix_productVector(MinR, matRes, MinRprime);
 /*   fprintf(stderr, "vect u : %f %f %f -> %f\n", MinR[0], MinR[1], MinR[2], */
 /* 	  MinR[0]*MinR[0] + MinR[1]*MinR[1] + MinR[2]*MinR[2]); */
-  Omega = acos(MinR[1]) * RADTODEG;
+  Omega = acos(CLAMP(MinR[1], -1.f, 1.f)) * RADTODEG;
   if (MinR[0] > 0.)
     Omega = -Omega;
   while (Omega - view->camera->omega < -90.)
