@@ -61,6 +61,7 @@
 /******************************************************************************/
 
 /* static int stereo; */
+static LightEnvironnement *currentLights;
 
 #define FLAG_PARAMETER_OPENGL_IMMEDIATE   "opengl_immediateDrawing"
 #define DESC_PARAMETER_OPENGL_IMMEDIATE   "If true, changes of parameters means immediate redrawing ; boolean 0 or 1"
@@ -116,8 +117,6 @@ int initOpengl()
 
   DBG_fprintf(stderr, "OpenGl: initialization.\n");
 
-  obj = gluNewQuadric();
-   
 /*   glViewport(0, 0, width, height); */
 
   /* Deals with lights. */
@@ -166,6 +165,11 @@ int initOpengl()
   return 1;
 }
 
+LightEnvironnement* openGLGet_currentLights()
+{
+  return currentLights;
+}
+
 /******************************************************************************/
 
 void setOpenGlMaterial(float* material, float* rgba)
