@@ -68,7 +68,7 @@ void setOpenGlMaterial(float* material, float* rgba);
 
 
 /* Object to deal with quadrics. */
-GLUquadricObj *obj;
+/* GLUquadricObj *obj; */
 
 /**
  * initOpengl:
@@ -82,7 +82,7 @@ GLUquadricObj *obj;
 int initOpengl();
 
 /* Objects to play with lights. */
-LightEnvironnement *currentLights;
+LightEnvironnement* openGLGet_currentLights();
 
 
 /* Draw methods */
