@@ -72,6 +72,7 @@
  */
 
 static int listCylinder;
+static PairsExtension* pointerToPairExtension_cylinder;
 
 #define FLAG_RESOURCES_PAIR_RADIUS "pairCylinder_pairRadius"
 #define DESC_RESOURCES_PAIR_RADIUS "This value is the radius for specific pairs drawn as cylinders ; element1 elemen2 0 < real < 10"
@@ -99,6 +100,11 @@ static gboolean exportResourcesCylinder(GString *data, int *nbLinesWritten,
 					VisuData *dataObj);
 
 
+PairsExtension* cylinderGet_static()
+{
+  return pointerToPairExtension_cylinder;
+}
+
 int setCylinderGeneralRadius(float val)
 {
   DBG_fprintf(stderr, "Pairs Cylinder : set the general cylinder radius to %f.\n", val);
@@ -366,8 +372,8 @@ static gboolean readLinkRadius(gchar **lines, int nbLines, int position,
       radius > RESOURCES_CYLINDER_RADIUS_MAX)
     {
       *error = g_error_new(CONFIG_FILE_ERROR, CONFIG_FILE_ERROR_VALUE,
-			   _("Parse error at line %d: radius must be in %g-%g.\n"),
-			   position, RESOURCES_CYLINDER_RADIUS_MIN,
+			   _("Parse error at line %d: radius (%g) must be in %g-%g.\n"),
+			   position, radius, RESOURCES_CYLINDER_RADIUS_MIN,
 			   RESOURCES_CYLINDER_RADIUS_MAX);
       return FALSE;
     }
