@@ -56,8 +56,9 @@
 #include <coreTools/toolColor.h>
 #include <coreTools/toolConfigFile.h>
 
-void changeLightForWire();
-void restoreLightAfterWire();
+static PairsExtension* pointerToPairExtension_wire;
+static void changeLightForWire();
+static void restoreLightAfterWire();
 
 /* This function details how to read what is needed by PairsData. */
 static gboolean readWireGeneralWidth(gchar **lines, int nbLines, int position,
@@ -101,6 +102,11 @@ static int wireWidth;
 static float **colorLengthSample;
 
 
+PairsExtension* wireGet_static()
+{
+  return pointerToPairExtension_wire;
+}
+
 static void beginPairLink(VisuElement *ele1 _U_, VisuElement *ele2 _U_,
 			  VisuPairData *data)
 {
@@ -226,12 +232,12 @@ PairsExtension* initPairsWire()
   return extension;
 }
 
-void changeLightForWire()
+static void changeLightForWire()
 {
   glDisable(GL_LIGHTING);
   glDisable(GL_DITHER);
 }
-void restoreLightAfterWire()
+static void restoreLightAfterWire()
 {
   glEnable(GL_DITHER); /* WARNING: it is the default! */
   glEnable(GL_LIGHTING);
@@ -460,31 +466,58 @@ void exportPairsWidth(VisuElement *ele1, VisuElement *ele2,
 {
   struct foreachFuncExport_struct *str;
   int *width;
+  guint16 *stipple;
+  gboolean output;
 
   width = (int*)visuPairGet_linkProperty(data, "width");
   if (width)
     {
       str = ( struct foreachFuncExport_struct*)userData;
+      output = TRUE;
       /* We export the resource only if the elements are
 	 part of the given VisuData. */
       if (str->dataObj)
 	{
 	  /* We test the first element. */
 	  if (!g_hash_table_lookup(str->dataObj->fromVisuElementToInt, ele1))
-	    return;
+	    output = FALSE;
 	  /* We test the second element. */
 	  if (!g_hash_table_lookup(str->dataObj->fromVisuElementToInt, ele2))
-	    return;
+	    output = FALSE;
 	}
-
-      g_string_append_printf(str->data,
-			     "%s:\n"
-			     "    %s %s  %4.3f %4.3f  %d\n",
-			     FLAG_RESOURCES_LINK_WIDTH,
-			     ele1->name, ele2->name, data->minMax[PAIRS_MIN],
-			     data->minMax[PAIRS_MAX], *width);
+      if (output)
+	g_string_append_printf(str->data,
+			       "%s:\n"
+			       "    %s %s  %4.3f %4.3f  %d\n",
+			       FLAG_RESOURCES_LINK_WIDTH,
+			       ele1->name, ele2->name, data->minMax[PAIRS_MIN],
+			       data->minMax[PAIRS_MAX], *width);
       *str->nbLinesWritten += 2;
     }
+  stipple = (guint16*)visuPairGet_linkProperty(data, "stipple");
+  if (stipple)
+    {
+      str = ( struct foreachFuncExport_struct*)userData;
+      output = TRUE;
+      /* We export the resource only if the elements are
+	 part of the given VisuData. */
+      if (str->dataObj)
+	{
+	  /* We test the first element. */
+	  if (!g_hash_table_lookup(str->dataObj->fromVisuElementToInt, ele1))
+	    output = FALSE;
+	  /* We test the second element. */
+	  if (!g_hash_table_lookup(str->dataObj->fromVisuElementToInt, ele2))
+	    output = FALSE;
+	}
+      if (output)
+	g_string_append_printf(str->data,
+			       "%s:\n"
+			       "    %s %s  %4.3f %4.3f  %d\n",
+			       FLAG_RESOURCES_LINK_STIPPLE,
+			       ele1->name, ele2->name, data->minMax[PAIRS_MIN],
+			       data->minMax[PAIRS_MAX], *stipple);
+    }
 }
 static gboolean exportResourcesWire(GString *data, int *nbLinesWritten,
 				    VisuData *dataObj)
