@@ -152,16 +152,16 @@ static void sync_local_resources(GObject *trash, gpointer data);
 /* See h file for more info */
 void panelElementSpinInit_gtkPanel()
 {
-  panelElements_setInterfaceMethods(pointerOnRenderingSpinMethod,
-				   changeSomethingSpin,
-				   createGtkInterfaceForSpinMethod);
+  panelElements_setInterfaceMethods(renderingSpinGet_static(),
+				    changeSomethingSpin,
+				    createGtkInterfaceForSpinMethod);
   currentListElement = (GList*)0;
 }
 
 /* See h file for more info */
 void panelElementSpinInit_gtkConfig()
 {
-  panelMethodSet_renderingInterface(pointerOnRenderingSpinMethod,
+  panelMethodSet_renderingInterface(renderingSpinGet_static(),
 				    createGtkConfigForSpinMethod,
 				    destroyGtkConfigForSpinMethod);
 }
@@ -433,7 +433,7 @@ GtkWidget* createGtkConfigForSpinMethod()
 
   gtk_widget_show_all(vbox);
 
-  configResourcesLoadedId = g_signal_connect(G_OBJECT(visu), "resourcesLoaded",
+  configResourcesLoadedId = g_signal_connect(VISU_INSTANCE, "resourcesLoaded",
 					     G_CALLBACK(sync_global_resources), NULL);
 
   return vbox;
@@ -441,7 +441,7 @@ GtkWidget* createGtkConfigForSpinMethod()
 void destroyGtkConfigForSpinMethod()
 {
   DBG_fprintf(stderr, "Gtk Spin : remove signal from config rendering widget.\n");
-  g_signal_handler_disconnect(G_OBJECT(visu), configResourcesLoadedId);
+  g_signal_handler_disconnect(VISU_INSTANCE, configResourcesLoadedId);
 }
 static void onPolicyChanged(GtkToggleButton *toggle, gpointer data)
 {
@@ -458,7 +458,7 @@ static void onPolicyAtomicChanged(GtkToggleButton *toggle, gpointer data _U_)
   if (rspin_setGlobalResource_boolean(spin_globalAtomic,
 				      gtk_toggle_button_get_active(toggle)))
     {
-      dataObj = toolPanelGet_visuData(TOOL_PANEL(panelElements));
+      dataObj = toolPanelGet_visuData(TOOL_PANEL(PANEL_ELEMENTS));
       if (!dataObj)
 	return;
 
@@ -488,7 +488,7 @@ static void onPolicyModulusChanged(GtkToggleButton *toggle, gpointer data)
   gtk_widget_set_sensitive(radioPerTypeMod, gtk_toggle_button_get_active(toggle));
   if (rspin_setGlobalResource_uint(spin_globalModulus, modPol))
     {
-      dataObj = toolPanelGet_visuData(TOOL_PANEL(panelElements));
+      dataObj = toolPanelGet_visuData(TOOL_PANEL(PANEL_ELEMENTS));
       if (!dataObj)
 	return;
 
@@ -501,7 +501,7 @@ static void onPolicyModulusChanged(GtkToggleButton *toggle, gpointer data)
    the spin rendering method. */
 void panelElementSpinInit_gtkMain()
 {
-  gtkMainClassSet_renderingSpecificMethods(pointerOnRenderingSpinMethod,
+  gtkMainClassSet_renderingSpecificMethods(renderingSpinGet_static(),
 					   gtkSpinCreate_fileChooser);
 }
 
@@ -540,7 +540,8 @@ static gboolean gtkSpinCreate_fileChooser(VisuData *data, GtkWindow *parent)
   gtk_window_set_position(GTK_WINDOW(fileSelection), GTK_WIN_POS_CENTER_ON_PARENT);
   gtk_window_set_modal(GTK_WINDOW(fileSelection), TRUE);
 
-  tmpLst = renderingMethodGet_fileType(pointerOnRenderingSpinMethod, FILE_KIND_POSITION);
+  tmpLst = renderingMethodGet_fileType(renderingSpinGet_static(),
+				       FILE_KIND_POSITION);
   filterPos = gtk_file_filter_new ();
   while(tmpLst)
     {
@@ -553,10 +554,10 @@ static gboolean gtkSpinCreate_fileChooser(VisuData *data, GtkWindow *parent)
       tmpLst = g_list_next(tmpLst);
     }
   gtk_file_filter_set_name(filterPos,
-			   renderingMethodGet_fileTypeName(pointerOnRenderingSpinMethod,
+			   renderingMethodGet_fileTypeName(renderingSpinGet_static(),
 							   FILE_KIND_POSITION));
 
-  tmpLst = renderingMethodGet_fileType(pointerOnRenderingSpinMethod, FILE_KIND_SPIN);
+  tmpLst = renderingMethodGet_fileType(renderingSpinGet_static(), FILE_KIND_SPIN);
   filterSpin = gtk_file_filter_new ();
   while(tmpLst)
     {
@@ -569,7 +570,7 @@ static gboolean gtkSpinCreate_fileChooser(VisuData *data, GtkWindow *parent)
       tmpLst = g_list_next(tmpLst);
     }
   gtk_file_filter_set_name(filterSpin,
-			   renderingMethodGet_fileTypeName(pointerOnRenderingSpinMethod,
+			   renderingMethodGet_fileTypeName(renderingSpinGet_static(),
 							   FILE_KIND_SPIN));
   filterAll = gtk_file_filter_new ();
   gtk_file_filter_add_pattern (filterAll, "*");
@@ -1010,7 +1011,7 @@ GtkWidget* createGtkInterfaceForSpinMethod()
 
   gtk_box_pack_start(GTK_BOX(vbox), expand, FALSE, FALSE, 0);
 
-  g_signal_connect(G_OBJECT(visu), "resourcesLoaded",
+  g_signal_connect(VISU_INSTANCE, "resourcesLoaded",
 		   G_CALLBACK(sync_local_resources), NULL);
 
   return vbox;
@@ -1101,7 +1102,7 @@ void onSpinBoundsChangeArrowSize(GObject *obj _U_, gfloat mult, gpointer data _U
   VisuData *dataObj;
   int id;
 
-  if (getRenderingMethodInUse() != pointerOnRenderingSpinMethod)
+  if (getRenderingMethodInUse() != renderingSpinGet_static())
     return;
 
   if (panelConfigGet_spinBoundsValue() == 1.)
@@ -1112,7 +1113,7 @@ void onSpinBoundsChangeArrowSize(GObject *obj _U_, gfloat mult, gpointer data _U
       gtk_label_set_use_markup(GTK_LABEL(labelSizeProp), TRUE);
     }
 
-  dataObj = toolPanelGet_visuData(TOOL_PANEL(panelElements));
+  dataObj = toolPanelGet_visuData(TOOL_PANEL(PANEL_ELEMENTS));
   for (i = 0; i < dataObj->ntype; i++)
     {
       for (j = 0; j < 6; j++)
@@ -1285,7 +1286,7 @@ void set_view(GtkWidget* button _U_, gpointer data _U_)
   VisuData *dataObj;
   OpenGLView *view;
 
-  dataObj = toolPanelGet_visuData(TOOL_PANEL(panelElements));
+  dataObj = toolPanelGet_visuData(TOOL_PANEL(PANEL_ELEMENTS));
   if (!dataObj)
     return;
   view = visuDataGet_openGLView(dataObj);
@@ -1318,7 +1319,7 @@ void redraw(int i)
 
   DBG_fprintf(stderr, "Gtk Spin : Updating rendering area.\n");
 
-  dataObj = toolPanelGet_visuData(TOOL_PANEL(panelElements));
+  dataObj = toolPanelGet_visuData(TOOL_PANEL(PANEL_ELEMENTS));
   if (!dataObj)
     return;
 
@@ -1337,8 +1338,8 @@ void redraw(int i)
   visuData_createAllNodes(dataObj);  
   
   if (i == 2)
-    g_signal_emit (visu, VISU_GET_CLASS (visu)->SpinAxes_signal_id,
-		   0 , dataObj, NULL);
+    g_signal_emit(VISU_INSTANCE, VISU_GET_CLASS(VISU_INSTANCE)->SpinAxes_signal_id,
+		  0 , dataObj, NULL);
   g_idle_add(visuObjectRedraw, (gpointer)0);
 }
 
