@@ -502,7 +502,7 @@ static GtkWidget *createInteriorBrowser()
 		   G_CALLBACK(onSpinDelayChangeValue), (gpointer)buttonPlayStop);
   g_signal_connect(G_OBJECT(buttonDumpAll), "clicked",
 		   G_CALLBACK(onDumpButtonClicked), (gpointer)0);
-  g_signal_connect(G_OBJECT(visu), "renderingChanged",
+  g_signal_connect(VISU_INSTANCE, "renderingChanged",
 		   G_CALLBACK(onRenderingChanged), (gpointer)0);
   g_signal_connect(G_OBJECT(entryFilterBrowser), "changed",
 		   G_CALLBACK(filterBrowserChanged), (gpointer)0);
