@@ -349,9 +349,7 @@ static void onRemoveClicked(GtkButton *button _U_, gpointer data _U_)
     return;
   extensionMap->used = 0;
   extensionLegend->used = 0;
-  g_signal_emit (visu, VISU_GET_CLASS (visu)->OpenGLAskForReDraw_signal_id,
-		 0 /* details */,
-		 NULL);
+  g_idle_add(visuObjectRedraw, (gpointer)0);
 }
 
 static void onDataNew(VisuObject *visu _U_, VisuData *dataObj, gpointer data _U_)
@@ -563,7 +561,7 @@ ToolPanel* panelMapInit()
   OpenGLExtensionSet_saveOpenGLState(extensionLegend, TRUE);
   OpenGLExtensionRegister(extensionLegend);
 
-  g_signal_connect(G_OBJECT(visu), "dataNew",
+  g_signal_connect(VISU_INSTANCE, "dataNew",
                    G_CALLBACK(onDataNew), (gpointer)0);
 
   return TOOL_PANEL(panelMap);
