@@ -184,9 +184,9 @@ void light_tree_show_hide(GtkCellRendererToggle *cell_renderer,
 
   light0->enabled = status;
 
-  status = lightEnvironnementApply(currentLights);
+  status = lightEnvironnementApply(openGLGet_currentLights());
   if (status)
-    g_signal_emit(visu, VISU_GET_CLASS (visu)->OpenGLAskForReDraw_signal_id, 0, NULL);
+    g_idle_add(visuObjectRedraw, (gpointer)0);
 }
 
 void light_update(GtkCellRendererText *cellrenderertext _U_,
@@ -211,9 +211,9 @@ void light_update(GtkCellRendererText *cellrenderertext _U_,
   else
     light0->position[GPOINTER_TO_INT(user_data)-LIGHT_POSITION0] = new_value;
 			 
-  status = lightEnvironnementApply(currentLights);
+  status = lightEnvironnementApply(openGLGet_currentLights());
   if (status)
-    g_signal_emit(visu, VISU_GET_CLASS (visu)->OpenGLAskForReDraw_signal_id, 0, NULL);
+    g_idle_add(visuObjectRedraw, (gpointer)0);
 }
 
 void light_sync_lists(GtkListStore *list)
@@ -221,7 +221,7 @@ void light_sync_lists(GtkListStore *list)
   g_return_if_fail(list);
 
   gtk_list_store_clear(list);
-  g_list_foreach(lightEnvironnementGet_lightList(currentLights),
+  g_list_foreach(lightEnvironnementGet_lightList(openGLGet_currentLights()),
 		 light_store_in_list_store, (gpointer)list);  
 }
 
@@ -383,7 +383,7 @@ void addNewLightClicked(GtkButton *button _U_, gpointer data)
     }
 
   light0 = light_newDefault();
-  status = lightEnvironnementAdd_light(currentLights, light0);
+  status = lightEnvironnementAdd_light(openGLGet_currentLights(), light0);
 
   if (!status)
     return;
@@ -397,9 +397,9 @@ void addNewLightClicked(GtkButton *button _U_, gpointer data)
 		     LIGHT_POSITION2, light0->position[2], 
 		     LIGHT_MULTIPLIER, light0->multiplier, -1);
 
-  status = lightEnvironnementApply(currentLights);
+  status = lightEnvironnementApply(openGLGet_currentLights());
   if (status)
-    g_signal_emit(visu, VISU_GET_CLASS (visu)->OpenGLAskForReDraw_signal_id, 0, NULL);
+    g_idle_add(visuObjectRedraw, (gpointer)0);
 }
 void removeSelectedLightsClicked(GtkButton *button _U_, gpointer data)
 {
@@ -427,7 +427,7 @@ void removeSelectedLightsClicked(GtkButton *button _U_, gpointer data)
 	  gtk_tree_model_get(GTK_TREE_MODEL(light_list_store), &iter,
 			     LIGHT_POINTER_TO, &light0,
 			     -1);
-	  lightEnvironnementDelete_light(currentLights, light0);
+	  lightEnvironnementDelete_light(openGLGet_currentLights(), light0);
 	  removableIter = g_malloc(sizeof(GtkTreeIter));
 	  *removableIter = iter;
 	  tmpLst->data = (gpointer)removableIter;
@@ -446,9 +446,9 @@ void removeSelectedLightsClicked(GtkButton *button _U_, gpointer data)
     }  
   g_list_free(selectedRows);
 
-  status = lightEnvironnementApply(currentLights);
+  status = lightEnvironnementApply(openGLGet_currentLights());
   if (status)
-    g_signal_emit(visu, VISU_GET_CLASS (visu)->OpenGLAskForReDraw_signal_id, 0, NULL);
+    g_idle_add(visuObjectRedraw, (gpointer)0);
 }
 void selectionChanged(GtkTreeSelection *tree, gpointer data)
 {
@@ -795,16 +795,16 @@ void addPresetOneLightClicked(GtkButton *button _U_, gpointer data)
 
   g_return_if_fail(data);
 
-  status = lightEnvironnementEmpty_lightList(currentLights);
+  status = lightEnvironnementEmpty_lightList(openGLGet_currentLights());
 
   light = light_newDefault();
-  status = lightEnvironnementAdd_light(currentLights, light) || status;
+  status = lightEnvironnementAdd_light(openGLGet_currentLights(), light) || status;
 
   light_sync_lists(GTK_LIST_STORE(data)); 
 
-  status = lightEnvironnementApply(currentLights) || status;
+  status = lightEnvironnementApply(openGLGet_currentLights()) || status;
   if (status)
-    g_signal_emit(visu, VISU_GET_CLASS (visu)->OpenGLAskForReDraw_signal_id, 0, NULL);
+    g_idle_add(visuObjectRedraw, (gpointer)0);
 }
 void addPresetFourLightsClicked(GtkButton *button _U_, gpointer data)
 {
@@ -813,33 +813,33 @@ void addPresetFourLightsClicked(GtkButton *button _U_, gpointer data)
 
   g_return_if_fail(data);
 
-  status = lightEnvironnementEmpty_lightList(currentLights);
+  status = lightEnvironnementEmpty_lightList(openGLGet_currentLights());
 
   light = light_newDefault();
   light->multiplier = 0.25;
-  status = lightEnvironnementAdd_light(currentLights, light) || status;
+  status = lightEnvironnementAdd_light(openGLGet_currentLights(), light) || status;
 
   light = light_newDefault();
   light->position[0] *= -1.;
   light->multiplier = 0.25;
-  status = lightEnvironnementAdd_light(currentLights, light) || status;
+  status = lightEnvironnementAdd_light(openGLGet_currentLights(), light) || status;
 
   light = light_newDefault();
   light->position[1] *= -1.;
   light->multiplier = 0.25;
-  status = lightEnvironnementAdd_light(currentLights, light) || status;
+  status = lightEnvironnementAdd_light(openGLGet_currentLights(), light) || status;
 
   light = light_newDefault();
   light->position[0] *= -1.;
   light->position[1] *= -1.;
   light->multiplier = 0.25;
-  status = lightEnvironnementAdd_light(currentLights, light) || status;
+  status = lightEnvironnementAdd_light(openGLGet_currentLights(), light) || status;
 
   light_sync_lists(GTK_LIST_STORE(data)); 
 
-  status = lightEnvironnementApply(currentLights) || status;
+  status = lightEnvironnementApply(openGLGet_currentLights()) || status;
   if (status)
-    g_signal_emit(visu, VISU_GET_CLASS (visu)->OpenGLAskForReDraw_signal_id, 0, NULL);
+    g_idle_add(visuObjectRedraw, (gpointer)0);
 }
 #if GTK_MINOR_VERSION > 5
 static void renderingModeEdited(GtkCellRendererText *cellrenderertext _U_,
@@ -892,6 +892,6 @@ static void renderingModeEdited(GtkCellRendererText *cellrenderertext _U_,
     }
 
   if (valid && ext->used)
-    g_signal_emit(visu, VISU_GET_CLASS (visu)->OpenGLAskForReDraw_signal_id, 0, NULL);
+    g_idle_add(visuObjectRedraw, (gpointer)0);
 }
 #endif
