@@ -186,7 +186,7 @@ ToolPanel* panelPlanesInit()
   OpenGLExtensionRegister(extensionPlanes);
 
   /* Add the signal for the vBoxPlanes. */
-  g_signal_connect(G_OBJECT(visu), "dataReadyForRendering",
+  g_signal_connect(VISU_INSTANCE, "dataReadyForRendering",
 		   G_CALLBACK(onDataReadyForRendering), (gpointer)0);
   g_signal_connect(G_OBJECT(panelPlanes), "page-entered",
 		   G_CALLBACK(onPlanesEnter), (gpointer)0);
@@ -250,7 +250,7 @@ static void createAndInitPlanePanel(VisuData *dataObj)
   isPlanesInitialised = TRUE;
   /* Force to connect signal if a file is already loaded. */
   if (dataObj)
-    onNewFileLoaded(visu, dataObj, (gpointer)0);
+    onNewFileLoaded(VISU_INSTANCE, dataObj, (gpointer)0);
 }
 
 static void onPlanesEnter(ToolPanel *planes, gpointer data _U_)
@@ -652,7 +652,7 @@ static void createInteriorPlanes(VisuData *dataObj)
   g_signal_connect(G_OBJECT(widgetColorPlane), "color-selected",
 		   G_CALLBACK(onPlaneColorChange), (gpointer)0);
 
-  g_signal_connect(G_OBJECT(visu), "dataNew",
+  g_signal_connect(VISU_INSTANCE, "dataNew",
 		   G_CALLBACK(onNewFileLoaded), (gpointer)0);
 
   g_signal_connect(gtk_tree_view_get_selection(GTK_TREE_VIEW(treeviewPlanes)),
@@ -810,9 +810,7 @@ void onPlaneUsed(GtkToggleButton *button, gpointer data _U_)
   if (res)
     visuData_createAllNodes(dataObj);
 
-  g_signal_emit (visu, VISU_GET_CLASS (visu)->OpenGLAskForReDraw_signal_id,
-		 0 /* details */,
-		 NULL);
+  g_idle_add(visuObjectRedraw, (gpointer)0);
 }
 void onPlaneAdd(GtkButton *button _U_, gpointer userData _U_)
 {
@@ -856,9 +854,7 @@ void onPlaneAdd(GtkButton *button _U_, gpointer userData _U_)
   if (gtk_tree_model_iter_n_children(GTK_TREE_MODEL(listStoredPlanes), (GtkTreeIter*)0) > 1)
     gtk_widget_set_sensitive(hboxHidingMode, TRUE);
   if (extensionPlanes->used)
-    g_signal_emit (visu, VISU_GET_CLASS (visu)->OpenGLAskForReDraw_signal_id,
-		   0 /* details */,
-		   NULL);
+    g_idle_add(visuObjectRedraw, (gpointer)0);
 }
 void onPlaneRemove(GtkButton *button _U_, gpointer data _U_)
 {
@@ -894,9 +890,7 @@ void onPlaneRemove(GtkButton *button _U_, gpointer data _U_)
       if (val)
 	visuData_createAllNodes(dataObj);
       if (extensionPlanes->used)
-	g_signal_emit (visu, VISU_GET_CLASS (visu)->OpenGLAskForReDraw_signal_id,
-		       0 /* details */,
-		       NULL);
+	g_idle_add(visuObjectRedraw, (gpointer)0);
 
       if (res)
 	gtk_tree_selection_select_iter(gtk_tree_view_get_selection(GTK_TREE_VIEW(treeviewPlanes)),
@@ -1114,9 +1108,7 @@ void onPlaneColorChange(ColorComboBox *combo, Color *color, gpointer data _U_)
   gtk_list_store_set(listStoredPlanes, &iter, COLUMN_PLANE_COLOR_PIXBUF, pixbufColorAlphaBox, -1);
   rebuildListPlanes(dataObj);
   if (extensionPlanes->used)
-    g_signal_emit (visu, VISU_GET_CLASS (visu)->OpenGLAskForReDraw_signal_id,
-		   0 /* details */,
-		   NULL);
+    g_idle_add(visuObjectRedraw, (gpointer)0);
 }
 
 static void onDataReadyForRendering(GObject *obj _U_, VisuData *dataObj,
@@ -1324,8 +1316,7 @@ void onSetCameraPosition(GtkButton *button _U_, gpointer data _U_)
       visuDataSet_angleOfView(toolPanelGet_visuData(TOOL_PANEL(panelPlanes)),
 			      spherical[1], spherical[2], 0.,
 			     MASK_THETA | MASK_PHI);
-      g_signal_emit (visu, VISU_GET_CLASS (visu)->OpenGLAskForReDraw_signal_id,
-		     0 , NULL);
+      g_idle_add(visuObjectRedraw, (gpointer)0);
     }
 }
 static void panelSet_rendered(GtkTreeIter *iter, Plane *plane, gboolean status)
@@ -1428,9 +1419,7 @@ void onGtkPlanesHideToggled(GtkCellRendererToggle *cell_renderer _U_,
       if (val)
 	{
 	  visuData_createAllNodes(dataObj);
-	  g_signal_emit (visu, VISU_GET_CLASS (visu)->OpenGLAskForReDraw_signal_id,
-			 0 /* details */,
-			 NULL);
+	  g_idle_add(visuObjectRedraw, (gpointer)0);
 	}
     }
 }
@@ -1472,9 +1461,7 @@ void onGtkPlanesHidingModeToggled(GtkToggleButton *toggle, gpointer data)
   if (res)
     {
       visuData_createAllNodes(dataObj);
-      g_signal_emit (visu, VISU_GET_CLASS (visu)->OpenGLAskForReDraw_signal_id,
-		     0 /* details */,
-		     NULL);
+      g_idle_add(visuObjectRedraw, (gpointer)0);
     }
 }
 gboolean panelPlanesApply_hidingScheme(VisuData *data)
@@ -1730,9 +1717,7 @@ static void onPlaneListOpen(GtkButton *button _U_, gpointer data _U_)
       res = panelPlanesApply_hidingScheme(dataObj);
       if (res)
 	visuData_createAllNodes(dataObj);
-      g_signal_emit (visu, VISU_GET_CLASS (visu)->OpenGLAskForReDraw_signal_id,
-		     0 /* details */,
-		     NULL);
+      g_idle_add(visuObjectRedraw, (gpointer)0);
     }
 }
 static gboolean callbackSave(gchar* filename)
