@@ -155,7 +155,7 @@ ToolPanel* panelConfigInit()
   visuConfigFileAdd_exportFunction(VISU_CONFIGFILE_PARAMETER,
 				   exportParametersPanelConfig);
 
-  defaultSkinPath = g_build_filename(v_sim_data_dir, "v_sim.rc", NULL);
+  defaultSkinPath = g_build_filename(V_SIM_DATA_DIR, "v_sim.rc", NULL);
   config_subPanelTabView = PARAMETER_CONFIG_TABVIEW_DEFAULT;
   config_refreshPeriod = -1;
   config_refreshIsOn = -1;
@@ -172,7 +172,7 @@ ToolPanel* panelConfigInit()
   isPanelConfigInitialized = FALSE;
 
   /* Set global callbacks. */
-  g_signal_connect(G_OBJECT(visu), "dataReadyForRendering",
+  g_signal_connect(VISU_INSTANCE, "dataReadyForRendering",
 		   G_CALLBACK(onDataReadySignal), (gpointer)0);
   g_signal_connect(G_OBJECT(visuConfigData), "page-entered",
 		   G_CALLBACK(onConfigEnter), (gpointer)0);
@@ -510,9 +510,7 @@ gboolean automaticReload(gpointer data)
 	  visuRenderingWindowSet_visuData(window, dataObj);
 	  visuData_createAllNodes(dataObj);
 	}
-
-      g_signal_emit (visu, VISU_GET_CLASS (visu)->OpenGLAskForReDraw_signal_id,
-		     0 , NULL);
+      visuObjectRedraw((gpointer)0);
     }
   return TRUE;
 }
