@@ -7,6 +7,7 @@
 #include <openbabel/math/vector3.h>
 
 #include <visu_tools.h>
+#include <visu_basic.h>
 #include <renderingMethods/renderingAtomic.h>
 #include <coreTools/toolColor.h>
 #include <coreTools/toolFileFormat.h>
@@ -55,7 +56,7 @@ gboolean obloaderInit()
   meth->load = loadOpenBabelFile;
   renderingAtomicAdd_loadMethod(meth);
 
-  iconPath = g_build_filename(v_sim_pixmaps_dir, "openbabel.png", NULL);
+  iconPath = g_build_filename(V_SIM_PIXMAPS_DIR, "openbabel.png", NULL);
 
   return TRUE;
 }
