@@ -48,6 +48,7 @@
 #include "nq_structure.h"
 #include "nq_density.h"
 #include <visu_tools.h>
+#include <visu_basic.h>
 #include <renderingMethods/renderingAtomic.h>
 
 #define NANOQUANTA_DESCRIPTION _("<span size=\"smaller\">" \
@@ -64,13 +65,12 @@ gboolean etsfInit()
   RenderingFormatLoad* meth;
 
   DBG_fprintf(stderr, "ETSF: loading plug-in 'nanoquanta'...\n");
-  NQ_ERROR = g_quark_from_string("nanoquanta");
 
   DBG_fprintf(stderr, "ETSF: declare a new rendering load method.\n");
   meth = nqStructuralInit();
   renderingAtomicAdd_loadMethod(meth);
 
-  iconPath = g_build_filename(v_sim_pixmaps_dir, "nanoquanta.png", NULL);
+  iconPath = g_build_filename(V_SIM_PIXMAPS_DIR, "nanoquanta.png", NULL);
 
   DBG_fprintf(stderr, "ETSF: declare a new density load method.\n");
   nqDensityInit();
@@ -93,6 +93,11 @@ const char* etsfGet_icon()
   return iconPath;
 }
 
+GQuark nqError_quark()
+{
+  return g_quark_from_static_string("nanoquanta");
+}
+
 
 
 gboolean nqOpen_netcdfFile(const char* filename, int *netcdfId, GError **error)
