@@ -44,6 +44,7 @@
 
 #include "xsf.h"
 #include <visu_tools.h>
+#include <visu_basic.h>
 #include <renderingMethods/renderingAtomic.h>
 #include <renderingMethods/renderingAtomic_ascii.h>
 #include <renderingMethods/renderingSpin.h>
@@ -82,7 +83,7 @@ gboolean xsfInit()
   spin = xsfSpinInit();
   rspin_addLoadMethod(spin);
 
-  iconPath = g_build_filename(v_sim_pixmaps_dir, "xsf.png", NULL);
+  iconPath = g_build_filename(V_SIM_PIXMAPS_DIR, "xsf.png", NULL);
 
   return TRUE;
 }
