@@ -45,6 +45,7 @@
 #include "renderingAtomic_ascii.h"
 #include "renderingAtomic_d3.h"
 #include "atomic_xyz.h"
+#include <visu_basic.h>
 #include <visu_elements.h>
 #include <visu_configFile.h>
 #include <renderingBackend/visu_windowInterface.h>
@@ -68,6 +69,8 @@
    describe the spheres. */
 /* int identifierSpheres; */
 
+static RenderingMethod* pointerOnRenderingAtomicMethod;
+
 /* The icosahedron drawing. */
 #define X .525731112119133606 
 #define Z .850650808352039932
@@ -174,7 +177,7 @@ RenderingMethod* initAtomic()
   atom = renderingMethod_new("Atom visualisation", name, descr,
 			     1, renderingAtomicLoad);
   renderingMethodSet_fileType(atom, formatList, 0, _("Position files"));
-  iconPath = g_build_filename(v_sim_pixmaps_dir, "stock-atomic.png", NULL);
+  iconPath = g_build_filename(V_SIM_PIXMAPS_DIR, "stock-atomic.png", NULL);
   renderingMethodSet_icon(atom, iconPath);
   g_free(iconPath);
   setOpenGLMethods(atom, renderingAtomic_createShape,
@@ -717,6 +720,9 @@ int renderingAtomic_createShape(VisuData *visuData, VisuElement* ele)
   struct atomicResources_struct *str;
   OpenGLView *view;
   int nlat, i, nfac;
+  GLUquadricObj *obj;
+
+  obj = gluNewQuadric();
 
   g_return_val_if_fail(visuData && ele, -1);
 
@@ -832,3 +838,8 @@ void renderingAtomicAdd_loadMethod(RenderingFormatLoad* meth)
   if (meth->fmt)
     renderingMethodAdd_fileFormat(pointerOnRenderingAtomicMethod, meth->fmt, 0);
 }
+
+RenderingMethod* renderingAtomicGet_static()
+{
+  return pointerOnRenderingAtomicMethod;
+}
