@@ -88,12 +88,12 @@ typedef enum
 RenderingMethod* initAtomic();
 
 /**
- * pointerOnRenderingAtomicMethod:
+ * renderingAtomicGet_static:
  *
  * This is a pointer to this rendering method.
  * It should be considered read-only.
  */
-RenderingMethod *pointerOnRenderingAtomicMethod;
+RenderingMethod* renderingAtomicGet_static();
 
 /**
  * renderingAtomicLoad:
