@@ -184,7 +184,7 @@ static int read_ascii_file(VisuData *data, FILE *flux, GError **error)
   double xu, yu, zu;
   unsigned int i;
   int res;
-  char nomloc[9], *ptChar;
+  char nomloc[MAX_LINE_LENGTH], *ptChar;
   VisuElement *type;
   VisuElement **types;
   unsigned int *nattyp;
