@@ -56,6 +56,7 @@
 #include "renderingAtomic_ascii.h"
 #include "renderingAtomic_d3.h"
 #include "atomic_xyz.h"
+#include <visu_basic.h>
 #include <visu_commandLine.h>
 #include <visu_configFile.h>
 #include <math.h>
@@ -73,6 +74,14 @@
 #define FLAG_RESOURCES_SPIN "spin_resources"
 #define DESC_RESOURCES_SPIN "Global or element resource for rendering spin module"
 
+/**
+ * pointerOnRenderingSpinMethod:
+ *
+ * This is a pointer to this rendering method.
+ * It should be considered read-only.
+ */
+static RenderingMethod *pointerOnRenderingSpinMethod;
+
 /* An identifier for the different shapes to draw elements. */
 enum
   {
@@ -282,12 +291,13 @@ RenderingMethod* initSpin()
 
   /* We check that the atomic rendering has been already defined, to use its own
      loader and file formats. */
-  if (!pointerOnRenderingAtomicMethod)
+  if (!renderingAtomicGet_static())
     {
       g_error("Can't initialize the RenderingSpin method,"
 	      " renderingAtomic must be initialized first. Aborting...\n");
     }
-  formatListPos = renderingMethodGet_fileType(pointerOnRenderingAtomicMethod, FILE_KIND_POSITION);
+  formatListPos = renderingMethodGet_fileType(renderingAtomicGet_static(),
+					      FILE_KIND_POSITION);
 
   /* We create the list of spin file formats. */
   formatListSpin = (GList*)0;
@@ -314,7 +324,7 @@ RenderingMethod* initSpin()
   renderingMethodSet_fileType(spin, formatListSpin, FILE_KIND_SPIN, _("Spin files"));
 
   /* Setting up the icon. */
-  iconPath = g_build_filename(v_sim_pixmaps_dir, "stock_spin.png", NULL);
+  iconPath = g_build_filename(V_SIM_PIXMAPS_DIR, "stock_spin.png", NULL);
   renderingMethodSet_icon(spin, iconPath);
   g_free(iconPath);
 
@@ -355,7 +365,7 @@ RenderingMethod* initSpin()
 
   /* Connect to the signal method changed to set or unset some variables
      when spin is current or not. */
-  g_signal_connect(G_OBJECT(visu), "renderingChanged",
+  g_signal_connect(VISU_INSTANCE, "renderingChanged",
 		   G_CALLBACK(onRenderingChanged), (gpointer)spin);
 
   /* Register a new NodeData. */
@@ -1504,8 +1514,7 @@ static void onSpinParametersChanged(VisuData *dataObj, VisuNode *node,
   DBG_fprintf(stderr, "Rendering Spin : callback when a spin parameter has been changed.\n");
 
   visuData_createNodes(dataObj, dataObj->fromIntToVisuElement[node->posElement]);
-  g_signal_emit(visu, VISU_GET_CLASS (visu)->OpenGLAskForReDraw_signal_id,
-		0 , NULL);
+  g_idle_add(visuObjectRedraw, (gpointer)0);
 }
 
 /*****************************************************************************/
@@ -1518,14 +1527,16 @@ static void onSpinParametersChanged(VisuData *dataObj, VisuNode *node,
 /*                                                                           */
 /*****************************************************************************/
 
-static void drawRoundedHat(float hat_length, float hat_height, float radius, int nlat)
+static void drawRoundedHat(GLUquadricObj *obj, float hat_length,
+			   float hat_height, float radius, int nlat)
 {
   gluCylinder(obj, hat_length, 0, hat_height, nlat, 1);
   glRotatef(180, 1, 0, 0);
   gluDisk(obj, 0, radius, nlat, 1);
   glRotatef(180, 1, 0, 0);
 }
-static void drawRoundedTail(float tail_length, float tail_height, int nlat)
+static void drawRoundedTail(GLUquadricObj *obj, float tail_length,
+			    float tail_height, int nlat)
 {
   glTranslatef(0, 0, -tail_height);
   glRotatef(180, 1, 0, 0);
@@ -1613,6 +1624,9 @@ int rspin_createShapeSpin(VisuData *visuData, VisuElement* ele)
   float hatLength, hatRadius, tailLength, tailRadius, *maxModulus, ratio, globalMax;
   struct spinResources_struct *str;
   OpenGLView *view;
+  GLUquadricObj *obj;
+
+  obj = gluNewQuadric();
 
   g_return_val_if_fail(visuData && ele, -1);
  
@@ -1668,26 +1682,30 @@ int rspin_createShapeSpin(VisuData *visuData, VisuElement* ele)
       if(str->use_element_color && str->use_element_color_hat)
 	{
 	  glCallList(visuElementGet_identifierMaterial(ele));
-	  drawRoundedHat(hatRadius, hatLength, MAX(hatRadius, tailRadius)*1.03, nlatl);
-	  drawRoundedTail(tailRadius, tailLength, nlatul);
+	  drawRoundedHat(obj, hatRadius,
+			 hatLength, MAX(hatRadius, tailRadius)*1.03, nlatl);
+	  drawRoundedTail(obj, tailRadius, tailLength, nlatul);
 	}
       else if(str->use_element_color)
 	{
-	  drawRoundedHat(hatRadius, hatLength, MAX(hatRadius, tailRadius)*1.03, nlatl);
+	  drawRoundedHat(obj, hatRadius, hatLength,
+			 MAX(hatRadius, tailRadius)*1.03, nlatl);
 	  glCallList(visuElementGet_identifierMaterial(ele));
-	  drawRoundedTail(tailRadius, tailLength, nlatul);
+	  drawRoundedTail(obj, tailRadius, tailLength, nlatul);
 	}
       else if(str->use_element_color_hat)
 	{
-	  drawRoundedTail(tailRadius, tailLength, nlatul);
+	  drawRoundedTail(obj, tailRadius, tailLength, nlatul);
 	  glTranslatef(0, 0, tailLength);
 	  glCallList(visuElementGet_identifierMaterial(ele));
-	  drawRoundedHat(hatRadius, hatLength, MAX(hatRadius, tailRadius)*1.03, nlatl);
+	  drawRoundedHat(obj, hatRadius, hatLength,
+			 MAX(hatRadius, tailRadius)*1.03, nlatl);
 	}
       else
 	{
-	  drawRoundedHat(hatRadius, hatLength, MAX(hatRadius, tailRadius)*1.03, nlatl);
-	  drawRoundedTail(tailRadius, tailLength, nlatul);
+	  drawRoundedHat(obj, hatRadius, hatLength,
+			 MAX(hatRadius, tailRadius)*1.03, nlatl);
+	  drawRoundedTail(obj, tailRadius, tailLength, nlatul);
 	}
       break;
     case shapeArrow2:
@@ -1923,3 +1941,8 @@ void rspin_placeNodeSpin(VisuData *visuData, VisuNode *node, VisuElement* ele)
 	}
     }
 }
+
+RenderingMethod* renderingSpinGet_static()
+{
+  return pointerOnRenderingSpinMethod;
+}
