@@ -51,14 +51,6 @@
 #include <visu_object.h>
 #include <visu_tools.h>
 
-/**
- * pointerOnRenderingSpinMethod:
- *
- * This is a pointer to this rendering method.
- * It should be considered read-only.
- */
-RenderingMethod *pointerOnRenderingSpinMethod;
-
 /**
  * SpinDrawingPolicy:
  * @policyAlwaysSpin: Arrows are drawn whatever the modulus value.
@@ -472,4 +464,6 @@ void rspin_placeNodeSpin(VisuData *visuData, VisuNode *node, VisuElement* ele);
  */
 void rspin_addLoadMethod(RenderingFormatLoad* meth);
 
+RenderingMethod* renderingSpinGet_static();
+
 #endif
