@@ -50,6 +50,8 @@
 #include "coreTools/toolFileFormat.h"
 #include "coreTools/toolOptions.h"
 
+G_BEGIN_DECLS
+
 /* Here, basic functions that don't require GTK, are defined. */
 
 /**
@@ -122,6 +124,14 @@ int visuBasicExport_main(void);
  * Returns: TRUE if no error occured.
  */
 gboolean visuBasicDump(VisuData *data);
+
+#define V_SIM_DATA_DIR           visuBasicGet_dataDir()
+#define V_SIM_LEGAL_DIR          visuBasicGet_legalDir()
+#define V_SIM_PIXMAPS_DIR        visuBasicGet_pixmapsDir()
+#define V_SIM_LOCAL_CONF_DIR     visuBasicGet_localDir()
+#define V_SIM_OLD_LOCAL_CONF_DIR visuBasicGet_oldLocalDir()
+#define V_SIM_PLUGINS_DIR        visuBasicGet_pluginsDir()
+#define V_SIM_LOCALE_DIR         visuBasicGet_localeDir()
 /**
  * visuBasicSet_paths:
  * @exeLocation: give argv[0] which is the complete path to the executable.
@@ -131,5 +141,14 @@ gboolean visuBasicDump(VisuData *data);
  * a v_sim.ini file found in the current directory or in the C:\windows.
  */
 void visuBasicSet_paths();
+const gchar* visuBasicGet_dataDir();
+const gchar* visuBasicGet_legalDir();
+const gchar* visuBasicGet_pixmapsDir();
+const gchar* visuBasicGet_localDir();
+const gchar* visuBasicGet_oldLocalDir();
+const gchar* visuBasicGet_pluginsDir();
+const gchar* visuBasicGet_localeDir();
+
+G_END_DECLS
 
 #endif
