@@ -45,6 +45,7 @@
 #include "visu_configFile.h"
 
 #include "visu_tools.h"
+#include "visu_basic.h"
 #include "visu_object.h"
 #include "coreTools/toolConfigFile.h"
 
@@ -803,7 +804,7 @@ int visuConfigFile_init()
   VisuConfigFileEntry *resourceEntry;
 
   DBG_fprintf(stderr, "Visu ConfigFile : initialization process ...");
-  CONFIG_FILE_ERROR = g_quark_from_string("visu_configFile");
+  configFileInit();
 
   visuConfigFile_entryList = g_hash_table_new_full(g_str_hash, g_str_equal,
 						   NULL, freeConfigEntry);
@@ -818,14 +819,14 @@ int visuConfigFile_init()
 
   resourcesPath = (GList*)0;
   parametersPath = (GList*)0;
-  resourcesPath = g_list_prepend(resourcesPath, (gpointer)v_sim_data_dir);
-  parametersPath = g_list_prepend(parametersPath, (gpointer)v_sim_data_dir);
+  resourcesPath = g_list_prepend(resourcesPath, (gpointer)V_SIM_DATA_DIR);
+  parametersPath = g_list_prepend(parametersPath, (gpointer)V_SIM_DATA_DIR);
 
-  resourcesPath = g_list_prepend(resourcesPath, (gpointer)v_sim_old_local_conf_dir);
-  parametersPath = g_list_prepend(parametersPath, (gpointer)v_sim_old_local_conf_dir);
+  resourcesPath = g_list_prepend(resourcesPath, (gpointer)V_SIM_OLD_LOCAL_CONF_DIR);
+  parametersPath = g_list_prepend(parametersPath, (gpointer)V_SIM_OLD_LOCAL_CONF_DIR);
 
-  resourcesPath = g_list_prepend(resourcesPath, (gpointer)v_sim_local_conf_dir);
-  parametersPath = g_list_prepend(parametersPath, (gpointer)v_sim_local_conf_dir);
+  resourcesPath = g_list_prepend(resourcesPath, (gpointer)V_SIM_LOCAL_CONF_DIR);
+  parametersPath = g_list_prepend(parametersPath, (gpointer)V_SIM_LOCAL_CONF_DIR);
 
   currentDir = g_get_current_dir();
   resourcesPath = g_list_prepend(resourcesPath, (gpointer)currentDir);
