@@ -53,8 +53,39 @@
 #include "coreTools/toolConfigFile.h"
 
 #include <GL/gl.h>
-#include <GL/glu.h> 
+#include <GL/glu.h>
 
+/**
+ * SECTION:visu_elements
+ * @short_description: defines methods to create and acccess to
+ * #VisuElement.
+ *
+ * <para>V_Sim is used to rendered at given position several object of
+ * the same kind. The #VisuElement object is used to control that
+ * kind. Typically, it corresponds to chemical element. It can
+ * represent the silicon, the iron...</para>
+ *
+ * <para>#VisuElement are defined by their name and have some
+ * characteristic like their color or if they are rendered or not. The
+ * color characteristic is defined by an RGBA array and different
+ * value for the behavior of the light, as defined in OpenGL :
+ * diffusivity, shiningness, emissivity, specular and ambient. These
+ * values can be controlled with the following methods :
+ * visuElementSet_allColorValues(), visuElementSet_allRGBValues(),
+ * visuElementSet_RGBValue(), visuElementSet_allMaterialValues() and
+ * visuElementSet_materialValue().</para>
+ *
+ * <para>Moreover, the user can add new properties to one element
+ * using visuElementSet_property() and visuElementGet_property(). The
+ * values stored with these functions are not copied and should be
+ * reachable until being remove or until the end of the
+ * program.</para>
+ *
+ * <para>If the OpenGL representation of one element is not dependent
+ * of its position, it is recommended to use the OpenGL list
+ * associated to each #VisuElement that can be accessed by a call to
+ * visuElementGet_identifierMaterial().</para>
+ */
 
 /**********************/
 /* Private prototypes */
@@ -62,37 +93,47 @@
 
 /* This is a pointer to the last added VisuElement. */
 /* VisuElement *lastAddedVisuElement; */
-int identifierMaterials;
+static int identifierMaterials;
 
 /* This hashtable contains a list of all different
    elements loaded in visu. ntype is _not_ the number of items
    in this hashtable. */
-GHashTable *differentVisuElements;
-GList *visuElement_list;
+static GHashTable *differentVisuElements;
+static GList *visuElement_list;
 
 /* This int stores how many user functions have needs
    to recreate the nodes of an element when its material
    has been changed. */
-int flagCreateNodesAfterMaterialChange;
+static int flagCreateNodesAfterMaterialChange;
 
 
-#define FLAG_RESOURCES_MAT "material"
-#define DESC_RESOURCES_MAT "Codes the main color in RedGreenBlue format and the light effects on material, eight floats between 0. and 1."
-#define FLAG_RESOURCES_ELE_RENDERED "element_is_rendered"
-#define DESC_RESOURCES_ELE_RENDERED "Define if the specified element is rendered or not."
+#define FLAG_ELEMENT_COLOR      "element_color"
+#define DESC_ELEMENT_COLOR      "Codes the main color in RedGreenBlueAlpha format" \
+  "and the light effects on material, nine floats between 0. and 1."
+#define FLAG_ELEMENT_PROPERTIES "element_properties"
+#define DESC_ELEMENT_PROPERTIES "Define some properties ; rendered (0 or 1) masked" \
+  "(0 or 1)."
 
 /* These functions detail how to read the RGB resource and
-   the material resource introduced by this part. */
-gboolean readMaterial(gchar **lines, int nbLines,
-		      int position, GString *errorMessage);
-gboolean readRendered(gchar **lines, int nbLines,
-		      int position, GString *errorMessage);
+   the material resource introduced by this part.
+   These routines are obsolete but kept for backward compatibility. */
+static gboolean readMaterial(gchar **lines, int nbLines, int position,
+			     VisuData *dataObj, GError **error);
+static gboolean readRendered(gchar **lines, int nbLines, int position,
+			     VisuData *dataObj, GError **error);
+
+/* Read routines for the config file. */
+static gboolean readElementColor(gchar **lines, int nbLines, int position,
+				 VisuData *dataObj, GError **error);
+static gboolean readElementProperties(gchar **lines, int nbLines, int position,
+				      VisuData *dataObj, GError **error);
+
 
 /* These functions write all the element list to export there associated resources. */
-gboolean exportResourcesRenderingBase(GString *data, int *nbLinesWritten,
-				      VisuData *dataObj);
+static gboolean exportResourcesRenderingBase(GString *data, int *nbLinesWritten,
+					     VisuData *dataObj);
 
-void freeHashValue(gpointer data);
+static void freeHashValue(gpointer data);
 
 
 
@@ -109,9 +150,9 @@ int visuElementAdd(VisuElement* element)
       nbElements = g_hash_table_size(differentVisuElements);
       if (nbElements == NMAX_TP)
 	{
-	  fprintf(stderr, "WARNING : the system requires more than %d elements."
-		  " This value is set at compile time with the variable NMAX_TP."
-		  " If you need more, ask the maintainer to raise this value.\n", NMAX_TP);
+	  g_warning("The system requires more than %d elements. This value is"
+		    " set at compilation time with the variable NMAX_TP. If you"
+		    " need more, ask the maintainer to raise this value.\n", NMAX_TP);
 	  return 1;
 	}
       element->typeNumber = g_hash_table_size(differentVisuElements);
@@ -122,189 +163,6 @@ int visuElementAdd(VisuElement* element)
   return 0;
 }
 
-VisuElement* visuElementRead_fromLine(char **line, int sizeMax, int position, GError **error)
-{
-  int i, res;
-  char element[36];
-  VisuElement *ele;
-  int avance, cont;
-
-  g_return_val_if_fail(error && (*error == (GError*)0), (VisuElement*)0);
-  g_return_val_if_fail(line && *line, (VisuElement*)0);
-
-  if (!line || !*line)
-    {
-      *error = g_error_new(CONFIG_FILE_ERROR, CONFIG_FILE_ERROR_EMPTY_LINE,
-			   _("WARNING! Parse error at line %d,"
-			     " line is empty.\n"), position);
-      return (VisuElement*)0;
-    }
-
-  avance = 0;
-  cont = 1;
-  for(i = 0; (sizeMax < 0 || i < sizeMax) && (*line)[i] && avance < 36 && cont; i++)
-    {
-      /* one character found */
-      if ( (*line)[i] != ' ' && (*line)[i] != '\t' &&
-	   (*line)[i] != '\n' && (*line)[i] != '\0' )
-	{
-	  element[avance] = (*line)[i];
-	  avance++;
-	}
-      /* one stopping character is found */
-      else if ((*line)[i] == ' ' || (*line)[i] == '\t')
-	{
-	  if (avance)
-	    cont = 0;
-	}
-      /* one error character is found */
-      else
-	{
-	  *error = g_error_new(CONFIG_FILE_ERROR, CONFIG_FILE_ERROR_BAD_ELEMENT_NAME,
-			       _("WARNING! Parse error at line %d,"
-				 " there is nothing after the element"
-				 " name.\n"), position);
-	  return (VisuElement*)0;
-	}
-    }
-  if (!avance)
-    {
-      *error = g_error_new(CONFIG_FILE_ERROR, CONFIG_FILE_ERROR_EMPTY_LINE,
-			   _("WARNING! Parse error at line %d,"
-			     " line is empty.\n"), position);
-      return (VisuElement*)0;
-    }
-    
-  *line = *line + i;
-
-  element[avance] = '\0';
-  /* 	      fprintf(stderr, " -> '%s'\n", element); */
-  /* Ok on a trouv un lment. Est-il dj connu? */
-  ele = (VisuElement*)
-    g_hash_table_lookup(differentVisuElements,
-			(gpointer)(element));
-  if (!ele)
-    {
-      ele = visuElementNewWithName(element);
-      if (ele)
-	{
-	  res = visuElementAdd(ele);
-	  if (res)
-	    {
-	      *error = g_error_new(CONFIG_FILE_ERROR, CONFIG_FILE_ERROR_MAX_ELEMENT,
-				   _("WARNING! Parse error at line %d,"
-				     " can't add this knew element,"
-				     " maximum (%d) has been reached.\n"), position, NMAX_TP);
-	      return (VisuElement*)0;
-	    }
-	}
-      else
-	*error = g_error_new(CONFIG_FILE_ERROR, CONFIG_FILE_ERROR_CREATED_ELEMENT,
-			     _("WARNING! Parse error at line %d,"
-			       " can't create this knew element.\n"), position);
-    }
-
-  return ele;
-}
-/* This method is a unified way to retrieve the
-   element at the beginning of line of value. */
-VisuElement* visuElementGet_fromValueLine(char **line, int sizeMax, int *errorFlag)
-{
-  int i, res;
-  char element[36];
-  VisuElement *ele;
-  int avance, cont;
-
-  if (!line || !*line)
-    {
-      *errorFlag = VISU_ELEMENT_EMPTY_LINE;
-      return (VisuElement*)0;
-    }
-
-  avance = 0;
-  cont = 1;
-  for(i = 0; (sizeMax < 0 || i < sizeMax) && (*line)[i] && avance < 36 && cont; i++)
-    {
-      /* one character found */
-      if ( (*line)[i] != ' ' && (*line)[i] != '\t' &&
-	   (*line)[i] != '\n' && (*line)[i] != '\0' )
-	{
-	  element[avance] = (*line)[i];
-	  avance++;
-	}
-      /* one stopping character is found */
-      else if ((*line)[i] == ' ' || (*line)[i] == '\t')
-	{
-	  if (avance)
-	    cont = 0;
-	}
-      /* one error character is found */
-      else
-	{
-	  *errorFlag = VISU_ELEMENT_BAD_NAME;
-	  return (VisuElement*)0;
-	}
-    }
-  if (!avance)
-    {
-      *errorFlag = VISU_ELEMENT_EMPTY_LINE;
-      return (VisuElement*)0;
-    }
-    
-  *line = *line + i;
-
-  element[avance] = '\0';
-  /* 	      fprintf(stderr, " -> '%s'\n", element); */
-  /* Ok on a trouv un lment. Est-il dj connu? */
-  ele = (VisuElement*)
-    g_hash_table_lookup(differentVisuElements,
-			(gpointer)(element));
-  if (!ele)
-    {
-      ele = visuElementNewWithName(element);
-      if (ele)
-	{
-	  res = visuElementAdd(ele);
-	  if (res)
-	    {
-	      *errorFlag = VISU_ELEMENT_MAX_REACHED;
-	      return (VisuElement*)0;
-	    }
-	}
-      else
-	*errorFlag = VISU_ELEMENT_CREATE_ERROR;
-    }
-
-  return ele;
-}
-
-void visuElementPrint_errorFromValueLine(GString *dest, int line, int flag)
-{
-  switch (flag)
-    {
-    case VISU_ELEMENT_EMPTY_LINE:
-      g_string_append_printf(dest, _("WARNING! Parse error at line %d,"
-						 " line is empty.\n"), line);
-      break;
-    case VISU_ELEMENT_BAD_NAME:
-      g_string_append_printf(dest, _("WARNING! Parse error at line %d,"
-						 " there is nothing after the element"
-						 " name.\n"), line);
-      break;
-    case VISU_ELEMENT_MAX_REACHED:
-      g_string_append_printf(dest, _("WARNING! Parse error at line %d,"
-						 " can't add this knew element,"
-						 " maximum (%d) has been reached.\n"),
-			     line, NMAX_TP);
-      break;
-    case VISU_ELEMENT_CREATE_ERROR:
-      g_string_append_printf(dest, _("WARNING! Parse error at line %d,"
-						 " can't create this knew element.\n"),
-			     line);
-      break;
-    }
-}
-
 GList* visuElementGet_allElements()
 {
   return visuElement_list;
@@ -428,38 +286,54 @@ int visuElementSet_materialValue(VisuElement* ele, int material, float value)
   else
     return 0;
 }
+int visuElementSet_sensitiveToPlanes(VisuElement *element, gboolean status)
+{
+  g_return_val_if_fail(element, 0);
 
-VisuElement *visuElementNewWithName(char *key)
+  if (element->sensitiveToMaskingPlanes == status)
+    return 0;
+
+  element->sensitiveToMaskingPlanes = status;
+  return 1;
+}
+gboolean visuElementGet_sensitiveToPlanes(VisuElement *element)
+{
+  g_return_val_if_fail(element, TRUE);
+  
+  return element->sensitiveToMaskingPlanes;
+}
+int visuElementSet_showNodeInfos(VisuElement *element, gboolean status)
+{
+  g_return_val_if_fail(element, 0);
+
+  if (element->showNodeInfos == status)
+    return 0;
+
+  element->showNodeInfos = status;
+  return 1;
+}
+gboolean visuElementGet_showNodeInfos(VisuElement *element)
+{
+  g_return_val_if_fail(element, FALSE);
+  
+  return element->showNodeInfos;
+}
+VisuElement *visuElementNew_withName(const char *key)
 {
   VisuElement *ele;
   int i;
 
-  ele = malloc(sizeof(VisuElement));
-  if (!ele)
-    {
-      allocationProblems();
-      return (VisuElement*)0;
-    }
-
-  ele->name = malloc(sizeof(char) * (strlen(key) + 1));
-  if (!ele->name)
-    {
-      allocationProblems();
-      return (VisuElement*)0;
-    }
-  strcpy(ele->name, key);
+  ele = g_malloc(sizeof(VisuElement));
+  ele->name = g_strdup(key);
   ele->typeNumber = -1;
   ele->materialIsUpToDate = FALSE;
   ele->rendered = TRUE;
+  ele->sensitiveToMaskingPlanes = TRUE;
+  ele->showNodeInfos = TRUE;
 
   ele->properties = g_hash_table_new_full(g_str_hash, g_str_equal,
-					  NULL, freeGPointer);
-  if (!ele)
-    {
-      allocationProblems();
-      return (VisuElement*)0;
-
-    }
+					  NULL, g_free);
+  g_return_val_if_fail(ele->properties, (VisuElement*)0);
 
   for (i = 0; i < 4; i++)
     ele->rgb[i] = 1.;
@@ -473,13 +347,10 @@ VisuElement *visuElementNewWithName(char *key)
 
 void visuElement_createMaterial(VisuElement *ele)
 {
-  float mm[4] = {0.0f, 0.0f, 0.0f, 0.0f};
-
   g_return_if_fail(ele);
 
-  DBG_fprintf(stderr, "Visu Elements : creating material for %s (ele id %d - OpenGL id %d)\n", ele->name, ele->typeNumber, identifierMaterials + ele->typeNumber);
+  DBG_fprintf(stderr, "Visu Elements: creating material for %s (ele id %d - OpenGL id %d)\n", ele->name, ele->typeNumber, identifierMaterials + ele->typeNumber);
 /*   fprintf(stderr, "%f %f %f - %f %f %f %f %f\n", ele->rgb[0], ele->rgb[1], ele->rgb[2], ele->material[0], ele->material[1], ele->material[2], ele->material[3], ele->material[4]); */
-  mm[3] = ele->rgb[3];
 
   glDeleteLists(identifierMaterials + ele->typeNumber, 1);
   glNewList(identifierMaterials + ele->typeNumber, GL_COMPILE);
@@ -490,14 +361,13 @@ void visuElement_createMaterial(VisuElement *ele)
 }
 
 /* return the OpenGL identifier of the specified VisuElement. */
-int visuElementGet_identifierMaterial(const VisuElement *ele)
+int visuElementGet_identifierMaterial(VisuElement *ele)
 {
   if (!ele)
     return 0;
-  if (!ele->materialIsUpToDate)
-    fprintf(stderr, "WARNING! Calling a material list not up to date for element '%s'.\n",
-	    ele->name);
-/*     visuElement_createMaterial((gpointer)ele->name, (gpointer)ele, (gpointer)0); */
+/*   if (!ele->materialIsUpToDate) */
+/*     visuElement_createMaterial(ele); */
+
   return identifierMaterials + ele->typeNumber;
 }
 
@@ -515,33 +385,46 @@ void visuElementUnset_updateNodesOnMaterialChange()
   DBG_fprintf(stderr, "Visu Element : set flagCreateNodesAfterMaterialChange to %d.\n",
 	      flagCreateNodesAfterMaterialChange);
 }
+gboolean visuElementGet_updateNodesOnMaterialChange()
+{
+  return (flagCreateNodesAfterMaterialChange > 0);
+}
 
 int initVisuElements()
 {
-  VisuConfigFileEntry *resourceEntry;
+  VisuConfigFileEntry *resourceEntry, *oldEntry;
 
   differentVisuElements =
     g_hash_table_new_full(g_str_hash, g_str_equal,
-			  (GDestroyNotify)freeString,
-			  (GDestroyNotify)freeHashValue);
-  if (!differentVisuElements)
-    {
-      allocationProblems();
-      return 0;
-    }
+			  g_free, (GDestroyNotify)freeHashValue);
+  g_return_val_if_fail(differentVisuElements, 0);
+
   visuElement_list = (GList*)0;
 /*   lastAddedVisuElement = (VisuElement*)0; */
 
   /* Create a VisuModule to registered the new resources as
      rgb and material. */
+  oldEntry = visuConfigFileAdd_entry(VISU_CONFIGFILE_RESOURCE,
+				     "material",
+				     "Obsolete entry for element_color",
+				     1, readMaterial);
   resourceEntry = visuConfigFileAdd_entry(VISU_CONFIGFILE_RESOURCE,
-					  FLAG_RESOURCES_MAT,
-					  DESC_RESOURCES_MAT,
-					  1, readMaterial);
+					  FLAG_ELEMENT_COLOR,
+					  DESC_ELEMENT_COLOR,
+					  1, readElementColor);
+  visuConfigFileSet_version(resourceEntry, 3.4f);
+  visuConfigFileSet_replace(resourceEntry, oldEntry);
+  oldEntry = visuConfigFileAdd_entry(VISU_CONFIGFILE_RESOURCE,
+				     "element_is_rendered",
+				     "Obsolete entry included in element_properties",
+				     1, readRendered);
+  visuConfigFileSet_version(resourceEntry, 3.1f);
   resourceEntry = visuConfigFileAdd_entry(VISU_CONFIGFILE_RESOURCE,
-					  FLAG_RESOURCES_ELE_RENDERED,
-					  DESC_RESOURCES_ELE_RENDERED,
-					  1, readRendered);
+					  FLAG_ELEMENT_PROPERTIES,
+					  DESC_ELEMENT_PROPERTIES,
+					  1, readElementProperties);
+  visuConfigFileSet_version(resourceEntry, 3.4f);
+  visuConfigFileSet_replace(resourceEntry, oldEntry);
   visuConfigFileAdd_exportFunction(VISU_CONFIGFILE_RESOURCE,
 				   exportResourcesRenderingBase);
 
@@ -557,94 +440,61 @@ int initVisuElements()
 /******************/
 /* Resources part */
 /******************/
-gboolean readMaterial(gchar **lines, int nbLines,
-		      int position, GString *errorMessage)
+static gboolean readElementColor(gchar **lines, int nbLines, int position,
+				 VisuData *dataObj _U_, GError **error)
 {
-  char *cursor;
   VisuElement* ele;
-  int res, errorFlag;
-  float rgb[4];
-  float material[5];
+  float all[9];
 
-  cursor = lines[0];
-  ele = visuElementGet_fromValueLine(&cursor, -1, &errorFlag);
-  if (!ele)
-    {
-      if (errorMessage)
-	visuElementPrint_errorFromValueLine(errorMessage, position, errorFlag);
-      return FALSE;
-    }
-  res = sscanf(cursor, "%f %f %f %f %f %f %f %f %f",
-	       &rgb[0], &rgb[1], &rgb[2], &rgb[3],
-	       &material[0],
-	       &material[1],
-	       &material[2],
-	       &material[3],
-	       &material[4]);
-  if (res != 9)
-    {
-      if (errorMessage)
-	g_string_append_printf(errorMessage, _("WARNING! Parse error at line %d,"
-						   " 8 floating point values (0 <= v"
-						   " <= 1) must appear after the"
-						   " material markup.\n"), position);
-      return FALSE;
-    }
-  res = 0;
-  res = res || visuConfigFileSet_floatValue(&rgb[0], rgb[0], 0., 1.);
-  res = res || visuConfigFileSet_floatValue(&rgb[1], rgb[1], 0., 1.);
-  res = res || visuConfigFileSet_floatValue(&rgb[2], rgb[2], 0., 1.);
-  res = res || visuConfigFileSet_floatValue(&rgb[3], rgb[3], 0., 1.);
-  res = res || visuConfigFileSet_floatValue(&material[0], material[0], 0., 1.);
-  res = res || visuConfigFileSet_floatValue(&material[1], material[1], 0., 1.);
-  res = res || visuConfigFileSet_floatValue(&material[2], material[2], 0., 1.);
-  res = res || visuConfigFileSet_floatValue(&material[3], material[3], 0., 1.);
-  res = res || visuConfigFileSet_floatValue(&material[4], material[4], 0., 1.);
-  if (res)
-    {
-      if (errorMessage)
-	g_string_append_printf(errorMessage, _("WARNING! Parse error at line %d,"
-					       " 8 floating point values (0 <= v"
-					       " <= 1) must appear after the material"
-					       " markup.\n"), position);
-      return FALSE;
-    }
-  visuElementSet_allColorValues(ele, rgb, material);
-  colorAdd_floatRGBA(rgb, (int*)0);
+  g_return_val_if_fail(nbLines == 1, FALSE);
+
+  if (!configFileRead_floatWithElement(lines[0], position, all, 9, &ele, error))
+    return FALSE;
+  ele->rgb[0] = CLAMP(all[0], 0., 1.);
+  ele->rgb[1] = CLAMP(all[1], 0., 1.);
+  ele->rgb[2] = CLAMP(all[2], 0., 1.);
+  ele->rgb[3] = CLAMP(all[3], 0., 1.);
+  ele->material[0] = CLAMP(all[4], 0., 1.);
+  ele->material[1] = CLAMP(all[5], 0., 1.);
+  ele->material[2] = CLAMP(all[6], 0., 1.);
+  ele->material[3] = CLAMP(all[7], 0., 1.);
+  ele->material[4] = CLAMP(all[8], 0., 1.);
+  colorAdd_floatRGBA(ele->rgb, (int*)0);
   
   return TRUE;
 }
-gboolean readRendered(gchar **lines, int nbLines,
-		      int position, GString *errorMessage)
+static gboolean readElementProperties(gchar **lines, int nbLines, int position,
+				 VisuData *dataObj _U_, GError **error)
 {
-  char *cursor;
   VisuElement* ele;
-  int res, errorFlag;
-  int rendered;
+  float values[2];
 
-  cursor = lines[0];
-  ele = visuElementGet_fromValueLine(&cursor, -1, &errorFlag);
-  if (!ele)
-    {
-      if (errorMessage)
-	visuElementPrint_errorFromValueLine(errorMessage, position, errorFlag);
-      return FALSE;
-    }
-  res = sscanf(cursor, "%d", &rendered);
-  if (res != 1)
-    {
-      if (errorMessage)
-	g_string_append_printf(errorMessage, _("WARNING! Parse error at line %d,"
-						   " 1 integer value (0 or"
-						   " 1) must appear after the"
-						   " element_is_rendered markup.\n"),
-			       position);
-      return FALSE;
-    }
-  if (rendered)
-    visuElementSet_rendered(ele, TRUE);
-  else
-    visuElementSet_rendered(ele, FALSE);
+  g_return_val_if_fail(nbLines == 1, FALSE);
+
+  if (!configFileRead_floatWithElement(lines[0], position, values, 2, &ele, error))
+    return FALSE;
+  visuElementSet_rendered(ele, (gboolean)values[0]);
+  visuElementSet_sensitiveToPlanes(ele, (gboolean)values[1]);
+  
+  return TRUE;
+}
+
+static gboolean readMaterial(gchar **lines, int nbLines, int position,
+			     VisuData *dataObj, GError **error)
+{
+  return readElementColor(lines, nbLines, position, dataObj, error);
+}
+static gboolean readRendered(gchar **lines, int nbLines, int position,
+			     VisuData *dataObj _U_, GError **error)
+{
+  VisuElement* ele;
+  float value;
+
+  g_return_val_if_fail(nbLines == 1, FALSE);
+
+  if (!configFileRead_floatWithElement(lines[0], position, &value, 1, &ele, error))
+    return FALSE;
+  visuElementSet_rendered(ele, (gboolean)value);
   
   return TRUE;
 }
@@ -654,9 +504,9 @@ gboolean exportResourcesRenderingBase(GString *data, int *nbLinesWritten,
 				      VisuData *dataObj)
 {
   GList *pos, *eleList;
-  int i;
+  unsigned int i;
 
-  g_string_append_printf(data, "# %s\n", DESC_RESOURCES_MAT);
+  g_string_append_printf(data, "# %s\n", DESC_ELEMENT_COLOR);
   *nbLinesWritten = 1;
   /* We create a list of elements, or get the whole list. */
   eleList = (GList*)0;
@@ -670,7 +520,7 @@ gboolean exportResourcesRenderingBase(GString *data, int *nbLinesWritten,
     pos = visuElementGet_allElements();
   while(pos)
     {
-      g_string_append_printf(data, "%s:\n", FLAG_RESOURCES_MAT);
+      g_string_append_printf(data, "%s:\n", FLAG_ELEMENT_COLOR);
       g_string_append_printf(data, "    %s %4.3f %4.3f %4.3f %4.3f"
 			     "   %4.2f %4.2f %4.2f %4.2f %4.2f\n",
 			     ((VisuElement*)pos->data)->name,
@@ -686,7 +536,7 @@ gboolean exportResourcesRenderingBase(GString *data, int *nbLinesWritten,
       *nbLinesWritten += 2;
       pos = g_list_next(pos);
     }
-  g_string_append_printf(data, "# %s\n", DESC_RESOURCES_ELE_RENDERED);
+  g_string_append_printf(data, "# %s\n", DESC_ELEMENT_PROPERTIES);
   *nbLinesWritten = 1;
   if (dataObj)
     pos = eleList;
@@ -694,13 +544,12 @@ gboolean exportResourcesRenderingBase(GString *data, int *nbLinesWritten,
     pos = visuElementGet_allElements();
   while(pos)
     {
-      if (!((VisuElement*)pos->data)->rendered)
-	{
-	  g_string_append_printf(data, "%s:\n", FLAG_RESOURCES_ELE_RENDERED);
-	  g_string_append_printf(data, "    %s 0\n",
-				 ((VisuElement*)pos->data)->name);
-	  *nbLinesWritten += 2;
-	}
+      g_string_append_printf(data, "%s:\n", FLAG_ELEMENT_PROPERTIES);
+      g_string_append_printf(data, "    %s %d %d\n",
+			     ((VisuElement*)pos->data)->name,
+			     ((VisuElement*)pos->data)->rendered,
+			     ((VisuElement*)pos->data)->sensitiveToMaskingPlanes);
+      *nbLinesWritten += 2;
       pos = g_list_next(pos);
     }
   g_string_append_printf(data, "\n");
@@ -711,55 +560,38 @@ gboolean exportResourcesRenderingBase(GString *data, int *nbLinesWritten,
   return TRUE;
 }
 
-void freeHashValue(gpointer data)
+static void freeHashValue(gpointer data)
 {
-  free(((VisuElement*)data)->name);
-  free((VisuElement*)data);
+  g_free(((VisuElement*)data)->name);
+  g_free((VisuElement*)data);
 }
 
 
 void visuElementSet_property(VisuElement* element, char* key, gpointer value)
 {
-  if (!element || !key)
-    {
-      fprintf(stderr, "WARNING! 'visuElementSet_property' has been called with"
-	      " a null element parameter or a null key parameter.\n");
-      return;
-    }
+  g_return_if_fail(element && key);
+
   DBG_fprintf(stderr, "Visu Element : set a new (key, value) to the element"
 	      " '%s' : ('%s', %p).\n", element->name, key, value);
   g_hash_table_insert(element->properties, (gpointer)key, (gpointer)value);
 }
 gpointer visuElementGet_property(const VisuElement* element, char* key)
 {
-  if (!element || !key)
-    {
-      fprintf(stderr, "WARNING! 'visuElementGet_property' has been called with"
-	      " a null element parameter or a null key parameter (%p, '%s').\n",
-	      (gpointer)element, key);
-      return (gpointer)0;
-    }
+  g_return_val_if_fail(element && key, (gpointer)0);
+
   return g_hash_table_lookup(element->properties, (gpointer)key);
 }
 void visuElementRemove_property(VisuElement* element, char* key)
 {
-  if (!element || !key)
-    {
-      fprintf(stderr, "WARNING! 'visuElementRemove_property' has been called with"
-	      " a null element parameter or a null key parameter.\n");
-      return;
-    }
+  g_return_if_fail(element && key);
+
   g_hash_table_remove(element->properties, (gpointer)key);
 }
 
 int visuElementSet_rendered(VisuElement *element, gboolean rendered)
 {
-  if (!element)
-    {
-      fprintf(stderr, "WARNING! 'visuElementSet_rendered' has been called"
-	      " with a null element parameter.\n");
-      return 0;
-    }
+  g_return_val_if_fail(element, 0);
+
   if (element->rendered == rendered)
     return 0;
 
@@ -768,16 +600,22 @@ int visuElementSet_rendered(VisuElement *element, gboolean rendered)
 }
 gboolean visuElementGet_rendered(VisuElement *element)
 {
-  if (!element)
-    {
-      fprintf(stderr, "WARNING! 'visuElementGet_rendered' has been called"
-	      " with a null element parameter.\n");
-      return 0;
-    }
+  g_return_val_if_fail(element, FALSE);
+
   return element->rendered;
 }
 
 
+/* Debug : print all informations about the specified VisuElement. */
+void debug_VisuElement(gpointer key, gpointer value, gpointer data _U_)
+{
+  VisuElement *ele;
+
+  ele = (VisuElement*)value;
+  fprintf(stderr, "Element '%s'\n", (gchar*)key);
+  fprintf(stderr, "  | rgba [%f %f %f %f]\n", ele->rgb[0], ele->rgb[1], ele->rgb[2], ele->rgb[3]);
+}
+
 /* Debug : print all informations about all the stored VisuElements. */
 void debug_AllVisuElements()
 {
@@ -785,12 +623,3 @@ void debug_AllVisuElements()
   g_hash_table_foreach(differentVisuElements, (GHFunc)debug_VisuElement, (gpointer)0);
 }
 
-/* Debug : print all informations about the specified VisuElement. */
-void debug_VisuElement(gpointer key, gpointer value, gpointer data)
-{
-  VisuElement *ele;
-
-  ele = (VisuElement*)value;
-  fprintf(stderr, "Element '%s'\n", ele->name);
-  fprintf(stderr, "  | rgba [%f %f %f %f]\n", ele->rgb[0], ele->rgb[1], ele->rgb[2], ele->rgb[3]);
-}
