@@ -66,8 +66,8 @@
 #include "panelModules/panelBrowser.h"
 #include "panelModules/panelDataFile.h"
 #include "panelModules/panelPlanes.h"
-#include "panelModules/panelSurfaces.h"
 #include "panelModules/panelMap.h"
+#include "panelModules/panelSurfaces.h"
 #include "panelModules/panelFogBgColor.h"
 #include "gtk_renderingWindowWidget.h"
 #include "extraGtkFunctions/gtk_colorComboBoxWidget.h"
@@ -331,93 +331,111 @@ void visuGtkPreview_update(VisuGtkPreview *preview, const char *filenames[])
 	      width = 150;
 	      height = 150;
 	      dumpData = visuOpenGLNew_pixmapContext((guint)width, (guint)height);
-	      /* We set the glViewport of this new context. */
-	      glViewport(0, 0, width, height);
-	      /* We call the given draw method. */
-	      openGLInit_context();
-	      visuDataSet_sizeOfView(data, (guint)width, (guint)height);
-	      openGLViewCompute_matrixAndView(visuDataGet_openGLView(data));
-	      OpenGLExtensionRebuild_list(data, EXT_FOG_AND_BG_ID);
-	      OpenGLExtensionRebuild_list(data, EXT_VISU_DATA_ID);
-	      OpenGLExtensionRebuild_list(data, EXT_BOX_ID);
-	      glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);
-	      OpenGLExtensionCall_list(EXT_FOG_AND_BG_ID);
-	      OpenGLExtensionCall_list(EXT_VISU_DATA_ID);
-	      OpenGLExtensionCall_list(EXT_BOX_ID);
-	      /* We copy the pixmap into generic data. */
-	      image = visuOpenGLGet_pixmapData((guint)width, (guint)height, FALSE);
-	      /* We free the pixmap context. */
-	      visuOpenGLFree_pixmapContext(dumpData);
-	      pixbuf = gdk_pixbuf_new_from_data((guchar*)image, GDK_COLORSPACE_RGB,
-						FALSE, 8, width, height, 3 * width,
-						free_image, (gpointer)0);
-	      gtk_image_set_from_pixbuf(GTK_IMAGE(preview->image), pixbuf);
-	      gdk_pixbuf_unref(pixbuf);
-	      /* Set the rendering window current for OpenGL. */
-	      renderingWindowSet_current(currentRenderingWindow, TRUE);
-	      /* We reset the flag of material. */
-	      comment = visuDataGet_fileCommentary(data, 0);
-	      visuDataIter_new(data, &iter);
-	      nRows = (comment && comment[0])?iter.nElements + 3:iter.nElements + 1;
-	      preview->table = gtk_table_new(iter.nElements + 1, 2, FALSE);
-	      wd = gtk_label_new(_("<i>Box composition:</i>"));
-	      gtk_label_set_use_markup(GTK_LABEL(wd), TRUE);
-	      gtk_misc_set_alignment(GTK_MISC(wd), 0., 0.5);
-	      gtk_table_attach(GTK_TABLE(preview->table), wd, 0, 2, 0, 1,
-			       GTK_FILL | GTK_EXPAND, GTK_SHRINK, 2, 5);
-	      for (visuDataIter_start(data, &iter); iter.element;
-		   visuDataIter_nextElement(data, &iter))
+	      if (dumpData)
 		{
-		  iter.element->materialIsUpToDate = FALSE;
-		  wd = gtk_label_new("");
-		  text = g_markup_printf_escaped
-		    (_("<span size=\"small\"><b>%s:</b></span>"), iter.element->name);
-		  gtk_label_set_markup(GTK_LABEL(wd), text);
-		  gtk_misc_set_alignment(GTK_MISC(wd), 1., 0.5);
-		  g_free(text);
-		  gtk_table_attach(GTK_TABLE(preview->table), wd, 0, 1,
-				   iter.iElement + 1, iter.iElement + 2,
-				   GTK_FILL, GTK_SHRINK, 2, 0);
-		  wd = gtk_label_new("");
-		  if (iter.nStoredNodes[iter.iElement] > 1)
-		    text = g_markup_printf_escaped
-		      (_("<span size=\"small\">%d nodes</span>"),
-		       iter.nStoredNodes[iter.iElement]);
-		  else
-		    text = g_markup_printf_escaped
-		      (_("<span size=\"small\">%d node</span>"),
-		       iter.nStoredNodes[iter.iElement]);
-		  gtk_label_set_markup(GTK_LABEL(wd), text);
-		  gtk_misc_set_alignment(GTK_MISC(wd), 0., 0.5);
-		  g_free(text);
-		  gtk_table_attach(GTK_TABLE(preview->table), wd, 1, 2,
-				   iter.iElement + 1, iter.iElement + 2,
-				   GTK_FILL | GTK_EXPAND, GTK_SHRINK, 2, 0);
-		}
-	      if (comment && comment[0])
-		{
-		  wd = gtk_label_new(_("<i>Description:</i>"));
+		  /* We set the glViewport of this new context. */
+		  glViewport(0, 0, width, height);
+		  /* We call the given draw method. */
+		  openGLInit_context();
+		  visuDataSet_sizeOfView(data, (guint)width, (guint)height);
+		  openGLViewCompute_matrixAndView(visuDataGet_openGLView(data));
+		  OpenGLExtensionRebuild_list(data, EXT_FOG_AND_BG_ID);
+		  OpenGLExtensionRebuild_list(data, EXT_VISU_DATA_ID);
+		  OpenGLExtensionRebuild_list(data, EXT_BOX_ID);
+		  glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);
+		  OpenGLExtensionCall_list(EXT_FOG_AND_BG_ID);
+		  OpenGLExtensionCall_list(EXT_VISU_DATA_ID);
+		  OpenGLExtensionCall_list(EXT_BOX_ID);
+		  /* We copy the pixmap into generic data. */
+		  image = visuOpenGLGet_pixmapData((guint)width,
+						   (guint)height, FALSE);
+		  /* We free the pixmap context. */
+		  visuOpenGLFree_pixmapContext(dumpData);
+		  pixbuf =
+		    gdk_pixbuf_new_from_data((guchar*)image, GDK_COLORSPACE_RGB,
+					     FALSE, 8, width, height, 3 * width,
+					     free_image, (gpointer)0);
+		  gtk_image_set_from_pixbuf(GTK_IMAGE(preview->image), pixbuf);
+		  gdk_pixbuf_unref(pixbuf);
+		  /* Set the rendering window current for OpenGL. */
+		  renderingWindowSet_current(currentRenderingWindow, TRUE);
+		  /* We reset the flag of material. */
+		  comment = visuDataGet_fileCommentary(data, 0);
+		  visuDataIter_new(data, &iter);
+		  nRows = (comment && comment[0])?
+		    iter.nElements + 3:iter.nElements + 1;
+		  preview->table = gtk_table_new(iter.nElements + 1, 2, FALSE);
+		  wd = gtk_label_new(_("<i>Box composition:</i>"));
 		  gtk_label_set_use_markup(GTK_LABEL(wd), TRUE);
 		  gtk_misc_set_alignment(GTK_MISC(wd), 0., 0.5);
-		  gtk_table_attach(GTK_TABLE(preview->table), wd, 0, 2,
-				   iter.nElements + 2, iter.nElements + 3,
+		  gtk_table_attach(GTK_TABLE(preview->table), wd, 0, 2, 0, 1,
 				   GTK_FILL | GTK_EXPAND, GTK_SHRINK, 2, 5);
-		  wd = gtk_label_new("");
-		  text = g_markup_printf_escaped("<span size=\"small\">%s</span>",
-						 comment);
-		  gtk_label_set_markup(GTK_LABEL(wd), text);
-		  g_free(text);
-		  gtk_misc_set_alignment(GTK_MISC(wd), 0., 0.5);
-		  gtk_label_set_justify(GTK_LABEL(wd), GTK_JUSTIFY_FILL);
-		  gtk_label_set_line_wrap(GTK_LABEL(wd), TRUE);
-		  gtk_widget_set_size_request(wd, 150, -1);
-		  gtk_table_attach(GTK_TABLE(preview->table), wd, 0, 2,
-				   iter.nElements + 3, iter.nElements + 4,
-				   GTK_FILL | GTK_EXPAND, GTK_SHRINK, 2, 0);
+		  for (visuDataIter_start(data, &iter); iter.element;
+		       visuDataIter_nextElement(data, &iter))
+		    {
+		      iter.element->materialIsUpToDate = FALSE;
+		      wd = gtk_label_new("");
+		      text = g_markup_printf_escaped
+			(_("<span size=\"small\"><b>%s:</b></span>"),
+			 iter.element->name);
+		      gtk_label_set_markup(GTK_LABEL(wd), text);
+		      gtk_misc_set_alignment(GTK_MISC(wd), 1., 0.5);
+		      g_free(text);
+		      gtk_table_attach(GTK_TABLE(preview->table), wd, 0, 1,
+				       iter.iElement + 1, iter.iElement + 2,
+				       GTK_FILL, GTK_SHRINK, 2, 0);
+		      wd = gtk_label_new("");
+		      if (iter.nStoredNodes[iter.iElement] > 1)
+			text = g_markup_printf_escaped
+			  (_("<span size=\"small\">%d nodes</span>"),
+			   iter.nStoredNodes[iter.iElement]);
+		      else
+			text = g_markup_printf_escaped
+			  (_("<span size=\"small\">%d node</span>"),
+			   iter.nStoredNodes[iter.iElement]);
+		      gtk_label_set_markup(GTK_LABEL(wd), text);
+		      gtk_misc_set_alignment(GTK_MISC(wd), 0., 0.5);
+		      g_free(text);
+		      gtk_table_attach(GTK_TABLE(preview->table), wd, 1, 2,
+				       iter.iElement + 1, iter.iElement + 2,
+				       GTK_FILL | GTK_EXPAND, GTK_SHRINK, 2, 0);
+		    }
+		  if (comment && comment[0])
+		    {
+		      wd = gtk_label_new(_("<i>Description:</i>"));
+		      gtk_label_set_use_markup(GTK_LABEL(wd), TRUE);
+		      gtk_misc_set_alignment(GTK_MISC(wd), 0., 0.5);
+		      gtk_table_attach(GTK_TABLE(preview->table), wd, 0, 2,
+				       iter.nElements + 2, iter.nElements + 3,
+				       GTK_FILL | GTK_EXPAND, GTK_SHRINK, 2, 5);
+		      wd = gtk_label_new("");
+		      text = g_markup_printf_escaped("<span size=\"small\">%s</span>",
+						     comment);
+		      gtk_label_set_markup(GTK_LABEL(wd), text);
+		      g_free(text);
+		      gtk_misc_set_alignment(GTK_MISC(wd), 0., 0.5);
+		      gtk_label_set_justify(GTK_LABEL(wd), GTK_JUSTIFY_FILL);
+		      gtk_label_set_line_wrap(GTK_LABEL(wd), TRUE);
+		      gtk_widget_set_size_request(wd, 150, -1);
+		      gtk_table_attach(GTK_TABLE(preview->table), wd, 0, 2,
+				       iter.nElements + 3, iter.nElements + 4,
+				       GTK_FILL | GTK_EXPAND, GTK_SHRINK, 2, 0);
+		    }
+		  gtk_box_pack_start(GTK_BOX(preview->vbox), preview->table,
+				     FALSE, FALSE, 0);
+		  gtk_widget_show_all(preview->table);
+		}
+	      else
+		{
+		  gtk_image_set_from_stock(GTK_IMAGE(preview->image),
+					   GTK_STOCK_DIALOG_ERROR,
+					   GTK_ICON_SIZE_DIALOG);
+		  wd = gtk_label_new(_("Internal error, no preview available"));
+		  gtk_box_pack_start(GTK_BOX(preview->vbox), wd,
+				     FALSE, FALSE, 0);
+		  gtk_widget_show_all(wd);
+		  preview->table = wd;
 		}
-	      gtk_box_pack_start(GTK_BOX(preview->vbox), preview->table,
-				 FALSE, FALSE, 0);
-	      gtk_widget_show_all(preview->table);
 	    }
 	}
       /* We free the VisuData. */
@@ -573,8 +591,8 @@ int visuGtkMain(int argc, char *argv[])
   gdk_gl_init(&argc, &argv);
 #endif
 
-  /* Creating the visu object to handle the signals. */
-  visu = g_object_new (VISU_TYPE, NULL);
+  /* Force the creation of the main object class. */
+  g_type_class_ref(visu_get_type());
 
   /* Set private variables. */
   usePreview = TRUE;
@@ -661,7 +679,8 @@ static gboolean initVisuPostGTK(gpointer data)
 	}
       g_free(path);
       DBG_fprintf(stderr, "Visu Gtk: emit 'resource-loaded' signal.\n");
-      g_signal_emit(visu, VISU_GET_CLASS(visu)->resourcesLoaded_signal_id,
+      g_signal_emit(VISU_INSTANCE,
+		    VISU_GET_CLASS(VISU_INSTANCE)->resourcesLoaded_signal_id,
 		    0, (GObject*)0, NULL);
     }
 
@@ -670,7 +689,7 @@ static gboolean initVisuPostGTK(gpointer data)
   spin_filename = commandLineGet_ArgSpinFileName();
   if (spin_filename && filename)
     {
-      setRenderingMethodInUse(pointerOnRenderingSpinMethod);
+      setRenderingMethodInUse(renderingSpinGet_static());
       newData = visuDataNew();
       if (!newData)
 	exit(1);
@@ -693,7 +712,7 @@ static gboolean initVisuPostGTK(gpointer data)
     }
   else if (filename)
     {
-      setRenderingMethodInUse(pointerOnRenderingAtomicMethod);
+      setRenderingMethodInUse(renderingAtomicGet_static());
       newData = visuDataNew();
       if (!newData)
 	exit(1);
