@@ -50,6 +50,9 @@ struct _VisuObjectPrivate
   int toto;
 };
 
+/* All signal emit by visu are handled by this ogbject. */
+static GObject *visu;
+
 static void
 visu_instance_init (GTypeInstance   *instance,
 		    gpointer         g_class _U_)
@@ -162,6 +165,9 @@ visu_class_init (gpointer g_class,
                                G_TYPE_NONE /* return_type */,
                                1     /* n_params */,
                                paramObject  /* param_types */);
+
+  /* Creating the visu object to handle the signals. */
+  visu = g_object_new(VISU_TYPE, NULL);
 }
 
 GType visu_get_type (void)
@@ -199,3 +205,8 @@ gboolean visuObjectRedraw(gpointer data)
   
   return FALSE;
 }
+
+GObject* visuObjectGet_static()
+{
+  return visu;
+}
