@@ -190,7 +190,7 @@ void initPick_module()
 
   /* We listen to the dataReadyForRendering signal to create a pickMesure
      object and attach it to an object when created. */
-  g_signal_connect(G_OBJECT(visu), "dataNew",
+  g_signal_connect(VISU_INSTANCE, "dataNew",
 		   G_CALLBACK(createPickMesureOnNewData), (gpointer)0);
 
   /* Initialize an extension to draw the marks. */
@@ -360,6 +360,7 @@ static void drawMarkDot(VisuData *data, VisuNode *node, PickMesureMarkType type)
   int nlat;
   float eleSize, rgba[4], material[5];
   RenderingMethod *method;
+  GLUquadricObj *obj;
 
   /* If the node is masked, then we don't draw the dot. */
   if (!node->rendered)
@@ -393,6 +394,7 @@ static void drawMarkDot(VisuData *data, VisuNode *node, PickMesureMarkType type)
 		   GL_RGBA, GL_UNSIGNED_BYTE, pickMesureMark_smallSquare);
       break;
     case PICK_MESURE_MARK_HIGHLIGHT:
+      obj = gluNewQuadric();
       method = getRenderingMethodInUse();
       eleSize = renderingMethodGet_sizeOfElement(method, ele);
       rgba[0] = 1. - ele->rgb[0];
