@@ -109,13 +109,13 @@ static gboolean exportFavRenderingMethod(GString *data, int *nbLinesWritten,
 
 /* A GHashTable to store all the available rendering methods
    in the system. The keys are the name of each method. */
-GHashTable *availableRenderingMethod;
-
+static GHashTable *availableRenderingMethod;
+static GQuark quark;
 /* The list of the available rendering method. */
-GList *listOfAvailableRenderingMethod;
+static GList *listOfAvailableRenderingMethod;
 
 /* A pointer to the in use rendering method. */
-RenderingMethod *renderingMethodInUse;
+static RenderingMethod *renderingMethodInUse;
 
 /* Local callbacks. */
 static void onResourcesLoaded(VisuObject *visu, VisuData *dataObj, gpointer data);
@@ -282,7 +282,7 @@ void setRenderingMethodInUse(RenderingMethod* method)
     }
   
   renderingMethodInUse = method;
-  g_signal_emit(visu, VISU_GET_CLASS(visu)->renderingChanged_signal_id,
+  g_signal_emit(VISU_INSTANCE, VISU_GET_CLASS(VISU_INSTANCE)->renderingChanged_signal_id,
 		0, (gpointer)method, NULL);
 }
 int setRenderingMethodByName(char* name)
@@ -351,7 +351,7 @@ int initRenderingMethods()
 
   g_return_val_if_fail(availableRenderingMethod, 0);
 
-  VISU_ERROR_RENDERING =  g_quark_from_string("visu_rendering");
+  quark =  g_quark_from_static_string("visu_rendering");
 
   res = 1;
   for (i = 0; listInitRendenringFunc[i]; i++)
@@ -368,11 +368,15 @@ int initRenderingMethods()
   DBG_fprintf(stderr, " %d valid rendering method(s) found.\n",
 	      g_hash_table_size(availableRenderingMethod));
 
-  g_signal_connect(G_OBJECT(visu), "resourcesLoaded",
+  g_signal_connect(VISU_INSTANCE, "resourcesLoaded",
  		   G_CALLBACK(onResourcesLoaded), (gpointer)0);
 
   return res;
 }
+GQuark renderingMethodGet_quark()
+{
+  return quark;
+}
 
 static void onResourcesLoaded(VisuObject *visu _U_, VisuData *dataObj,
 			      gpointer data _U_)
